SystemOrganization addCategory: #ConfigurationOfRoassal!

Object subclass: #ConfigurationOfRoassal
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfRoassal'!

!ConfigurationOfRoassal class methodsFor: 'development support' stamp: ''!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfRoassal class methodsFor: 'private' stamp: ''!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfRoassal class methodsFor: 'private' stamp: ''!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfRoassal class methodsFor: 'private' stamp: ''!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfRoassal class methodsFor: 'metacello tool support' stamp: ''!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfRoassal class methodsFor: 'loading' stamp: ''!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfRoassal class methodsFor: 'loading' stamp: ''!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfRoassal class methodsFor: 'loading' stamp: ''!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfRoassal class methodsFor: 'accessing' stamp: ''!
project

	^self new project! !

!ConfigurationOfRoassal class methodsFor: 'development support' stamp: ''!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfRoassal methodsFor: 'baselines' stamp: ''!
baseline10: spec
	<version: '0.0-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://www.squeaksource.com/Roassal'.
		spec package: #Roassal.
		spec group: 'default' with: #(#Roassal ). ].
! !

!ConfigurationOfRoassal methodsFor: 'baselines' stamp: 'AlexandreBergel 4/18/2012 14:16'!
baseline11: spec
	<version: '0.1-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://www.squeaksource.com/Roassal'.
		spec package: #Roassal.
		spec package: 'Roassal-Morphic'.
		spec group: 'default' with: #(#Roassal ). ].
! !

!ConfigurationOfRoassal methodsFor: 'baselines' stamp: 'AlexandreBergel 4/18/2012 15:17'!
baseline12: spec
	<version: '0.2-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://www.squeaksource.com/Roassal'.
		spec package: #Roassal.
		spec package: #RoassalMorphic.
		spec group: 'default' with: #(#Roassal #RoassalMorphic). ].
! !

!ConfigurationOfRoassal methodsFor: 'baselines' stamp: 'AlexandreBergel 12/13/2012 18:08'!
baseline13: spec
	<version: '0.3-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://www.squeaksource.com/Roassal'.
		spec 
			project: 'Fuel Core' with: [
				spec
					className: 'ConfigurationOfFuel';
					versionString: '1.8-baseline';
					file: 'ConfigurationOfFuel';
					repository: 'http://ss3.gemstone.com/ss/Fuel';
					loads: #('CoreWithExtras')].
		spec package: #Roassal.
		spec package: #RoassalMorphic with: [ spec requires: 'Fuel Core'].
		spec group: 'default' with: #(#Roassal #RoassalMorphic). ].! !

!ConfigurationOfRoassal methodsFor: 'baselines' stamp: 'AlexandreBergel 3/20/2013 09:25'!
baseline14: spec
	<version: '0.4-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: '1.287: Fixed Issue 303:	ifNil:ifNotNil: should not be used'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '3/20/2013 09:25'.
		spec repository: 'http://www.squeaksource.com/Roassal'.
		spec 
			package: #Roassal;
			package: #RoassalMorphic.
		spec 
			group: 'default' with: #(#Roassal #RoassalMorphic );
			group: 'Tests' with: #(#Roassal #RoassalMorphic ). ].
! !

!ConfigurationOfRoassal methodsFor: 'baselines' stamp: 'AlexandreBergel 4/12/2013 19:21'!
baseline15: spec
	<version: '0.5-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: '1.289 : cleaning and refactoring
1.290 : - Correctly implemented layout start, step and end announcement support.
- Fixed a bug related to layout creation.

Thanks Dennis Schenk!!
1.292 : removed unused method and added a comment
1.293 : added a small comment
1.294 : Fix by Juraj.
1.295 : fixing undeterministic tests with force layout
1.296 : Integrated many fixes
1.297 : Fixed Issue 307:	Bug when exporting SVG
1.298 : Added a superclass ROAbstractPopupTest. A bit of cleaning
1.299 : Fixed Issue 308:	Large popup in the wrong place
1.300 : Fixed Issue 309:	empty categories are listed in the examples
1.301 : Roassal example about drawing
1.302 : Fixed Issue 310:	Slow with inner nodes
1.303 : Having edges that show up when you enter a node is a recurrent need.
I have worked on some easy way to make this possible.

Using the Roassal low level api:
-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
| view rawView el1 el2 el3 |
rawView := ROView new.
rawView add: (el1 := ROBox element size: 20).
rawView add: (el2 := ROBox element size: 20).
rawView add: (el3 := ROBox element size: 20).
ROCircleLayout on: (Array with: el1 with: el2 with: el3).
	
el1 @ RODraggable.
el2 @ RODraggable.
el3 @ RODraggable.
	
el1 @ (RODynamicEdge toAll: (Array with: el2 with: el3) using: (ROLine arrowed color: Color red)).

rawView open
-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=


Using the Mondrian builder:
-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
view interaction 
	dynamicEdge: [ :model | (Array with: 10 with: 20 with: 30) copyWithout: model ]
	using: (ROLine arrowed color: Color red).
view shape rectangle size: 20.
view nodes: (Array with: 10 with: 20 with: 30).
view circleLayout.
-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=

1.304 : 
	- Fixed Issue 311:	ROHorizontalLineLayout>>positionOriginalPointer: buggy
	- cleaned a bit
	- testing ROPharoHTMLExporterTest
1.305 : Fixed Issue 311:	ROHorizontalLineLayout>>positionOriginalPointer: buggy
1.306 : merged
1.307 : Merged
1.308 : Fixing Roassal.Core.Tests.ROEventTest.testProperlyInitialized 
1.309 : Fixed Issue 312:	Bugfix for ROTreeMapLayout
1.310 : Fixed Issue 313:	RODynamicEdge cannot be combined
1.311 : Big big speed improvement
1.312 : 
Fixed Issue 314:	Freezing the image with Otho lines
	
Apparently lineSegmentsFor: returns an empty collection for Ortho lines. Which is obviously wrong.
1.312 : Fixed Issue 317:	expectedFailures in Roassal is not properly defined
	- merged with Vanessa code
	Added ROMondrianViewBuilder >> removeNodesAndEdgesOf: so Juampi can remove nodes and edges easily :D
- fixed issue: 315 with applying layout after removing and adding nodes 
- fixed RoassalSerializerExporterTest  expected failures
- tests added'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/12/2013 19:21'.
		spec repository: 'http://www.smalltalkhub.com/mc/ObjectProfile/Roassal/main'.
		spec 
			package: #Roassal;
			package: #RoassalMorphic.
		spec 
			group: 'default' with: #(#Roassal #RoassalMorphic );
			group: 'Tests' with: #(#Roassal #RoassalMorphic ). ].
! !

!ConfigurationOfRoassal methodsFor: 'baselines' stamp: 'TudorGirba 4/12/2013 21:11'!
baseline16: spec
	<version: '0.6-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec description: ''.
		spec author: 'TudorGirba'.
		spec timestamp: '4/11/2013 22:03'.
		spec repository: 'http://www.smalltalkhub.com/mc/ObjectProfile/Roassal/main'.
		spec 
			package: 'Roassal';
			package: 'RoassalMorphic' with: [ spec requires: 'Roassal' ];
			package: 'RoassalAthens' with: [ spec requires: #('RoassalMorphic' 'Athens') ].
		spec project: 'Athens' with: [
				spec
					className: 'ConfigurationOfAthens';
					file: 'ConfigurationOfAthens';
					version: '2.0';
					repository: 'http://www.smalltalkhub.com/mc/Pharo/Athens/main' ].
		spec 
			group: 'default' with: #('Roassal' 'RoassalMorphic');
			group: 'Tests' with: #('Roassal' 'RoassalMorphic');
			group: 'WithAthens' with: #('RoassalAthens')].! !

!ConfigurationOfRoassal methodsFor: 'symbolic versions' stamp: 'AlexandreBergel 4/11/2013 16:24'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '0.5-baseline'.
! !

!ConfigurationOfRoassal methodsFor: 'accessing' stamp: ''!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfRoassal methodsFor: 'symbolic versions' stamp: 'AlexandreBergel 4/11/2013 16:24'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '1.312'.
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/28/2012 17:17'!
version0129: spec
	<version: '0.129' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.128 : Removed a platform dependent method
0.129 : An edge with a null extremity cannot be added in the builder'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/28/2012 17:17'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.141';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.8'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/30/2012 09:38'!
version0130: spec
	<version: '0.130' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.129 : An edge with a null extremity cannot be added in the builder
0.130 : Added method complexity example'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/30/2012 09:38'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.143';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.8'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/30/2012 17:30'!
version0131: spec
	<version: '0.131' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.130 : Added method complexity example
0.131 : No popup and ViewStack that works well!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/30/2012 17:30'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.144';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.9'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/1/2012 16:39'!
version0132: spec
	<version: '0.132' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.131 : No popup and ViewStack that works well!!
0.132 : Fixed bug with misplaced popup'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/1/2012 16:39'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.145';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.9'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/1/2012 17:33'!
version0133: spec
	<version: '0.133' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.132 : Fixed bug with misplaced popup
0.133 : Added command example'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/1/2012 17:33'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.146';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.9'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/1/2012 17:43'!
version0134: spec
	<version: '0.134' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.133 : Added command example
0.134 : Added zoom. Try: ROMondrianExample new command'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/1/2012 17:43'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.147';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.9'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/1/2012 19:25'!
version0135: spec
	<version: '0.135' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.134 : Added zoom. Try: ROMondrianExample new command
0.135 : Added an easel'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/1/2012 19:25'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.147';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.10'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/2/2012 09:43'!
version0136: spec
	<version: '0.136' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.135 : Added an easel
0.136 : Added a zoom in and zoom out and find in the easel'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/2/2012 09:43'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.147';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.11'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/2/2012 10:41'!
version0137: spec
	<version: '0.137' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.136 : Added a zoom in and zoom out and find in the easel
0.137 : removed allPopups since it is not necessary and caused problem on VW (because of the WeakSet)'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/2/2012 10:41'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.148';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.12'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/2/2012 10:51'!
version0138: spec
	<version: '0.138' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.137 : removed allPopups since it is not necessary and caused problem on VW (because of the WeakSet)
0.138 : Added a highlight when finding a node in the easel.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/2/2012 10:51'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.148';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.13'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/3/2012 09:56'!
version0139: spec
	<version: '0.139' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.138 : Added a highlight when finding a node in the easel.
0.139 : bug fixed with popupView:
0.139 : Worked on the examples and fixed what Vanessa asked for'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/3/2012 09:56'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.150';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.14'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/3/2012 16:47'!
version0140: spec
	<version: '0.140' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.139 : Worked on the examples and fixed what Vanessa asked for
0.140 : added a rotimeorganizer. Useful for the VW port'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/3/2012 16:47'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.151';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.14'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/3/2012 17:11'!
version0141: spec
	<version: '0.141' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.140 : added a rotimeorganizer. Useful for the VW port
0.141 : Move a class to the right package.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/3/2012 17:11'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.152';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.15'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/3/2012 19:24'!
version0142: spec
	<version: '0.142' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.141 : Move a class to the right package.
0.142 : Added RODummyNode, else Sugiyama does not work'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/3/2012 19:24'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.153';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.15'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/3/2012 19:36'!
version0143: spec
	<version: '0.143' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.142 : Added RODummyNode, else Sugiyama does not work
0.143 : Added an example'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/3/2012 19:36'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.154';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.16'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/3/2012 19:40'!
version0144: spec
	<version: '0.144' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.143 : Added an example
0.144 : minor fix in the sugiyama layout'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/3/2012 19:40'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.155';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.16'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/4/2012 11:05'!
version0145: spec
	<version: '0.145' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.144 : minor fix in the sugiyama layout
0.145 : Worked on the tutorial. Added a ROSequenceInteraction'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/4/2012 11:05'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.156';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.17'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/4/2012 11:32'!
version0146: spec
	<version: '0.146' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.145 : Worked on the tutorial. Added a ROSequenceInteraction
0.146 : Fixed the tests for ROSequenceInteraction'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/4/2012 11:32'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.157';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.17'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/6/2012 10:35'!
version0147: spec
	<version: '0.147' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.146 : Fixed the tests for ROSequenceInteraction
0.147 : Bug fixed with clickToFocus'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/6/2012 10:35'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.158';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.18'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/7/2012 09:36'!
version0148: spec
	<version: '0.148' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.147 : Bug fixed with clickToFocus
0.148 : Minor cleaning'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/7/2012 09:36'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.159';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.18'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/7/2012 12:20'!
version0149: spec
	<version: '0.149' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.148 : Minor cleaning
0.149 : Renamed RODecorator into ROShape. It makes sense since RODecorator is not really the implementation of the decorator pattern anyway. Thanks Doru!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/7/2012 12:20'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.160';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.19'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/7/2012 18:14'!
version0150: spec
	<version: '0.150' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.149 : Renamed RODecorator into ROShape. It makes sense since RODecorator is not really the implementation of the decorator pattern anyway. Thanks Doru!!
0.150 : remove a super initialize in ROEvent.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/7/2012 18:14'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.161';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.19'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/7/2012 18:39'!
version0151: spec
	<version: '0.151' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.150 : remove a super initialize in ROEvent.
0.151 : Removed some old ref to ROMorph'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/7/2012 18:39'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.162';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.20'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/9/2012 16:48'!
version0152: spec
	<version: '0.152' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.151 : Removed some old ref to ROMorph
0.152 : fixed the tests for circle layout, a problem was due on VW because of the float rounding apparently.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/9/2012 16:48'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.163';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.20'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/10/2012 10:02'!
version0153: spec
	<version: '0.153' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.152 : fixed the tests for circle layout, a problem was due on VW because of the float rounding apparently.
0.153 : added a test for the unsubcription: for the event. And moved a test that is platform specific'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/10/2012 10:02'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.164';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.21'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/10/2012 22:11'!
version0154: spec
	<version: '0.154' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.153 : added a test for the unsubcription: for the event. And moved a test that is platform specific
0.154 : speeded up the rendering by about 50% by avoiding unnecessary form'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/10/2012 22:11'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.165';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.22'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/10/2012 22:30'!
version0155: spec
	<version: '0.155' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.154 : speeded up the rendering by about 50% by avoiding unnecessary form
0.155 : Removed unnecessary comment'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/10/2012 22:30'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.166';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.23'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/10/2012 22:50'!
version0156: spec
	<version: '0.156' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.155 : Removed unnecessary comment
0.156 : changed a == for a =. VW complained about it'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/10/2012 22:50'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.167';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.23'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/11/2012 10:13'!
version0157: spec
	<version: '0.157' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.156 : changed a == for a =. VW complained about it
0.157 :  Moved a benchmark into Pharo specific package'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/11/2012 10:13'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.168';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.24'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/11/2012 14:26'!
version0158: spec
	<version: '0.158' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.157 :  Moved a benchmark into Pharo specific package
0.158 : moved test from Roassal to MorphicSpecific'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/11/2012 14:26'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.170';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.26'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/13/2012 11:27'!
version0159: spec
	<version: '0.159' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.158 : moved test from Roassal to MorphicSpecific
0.159 : Expanded the tutorial'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/13/2012 11:27'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.173';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.28'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/15/2012 15:26'!
version0160: spec
	<version: '0.160' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.159 : Expanded the tutorial
0.160 : have used a moValue: instead of a roValue:'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/15/2012 15:26'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.174';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.28'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/17/2012 09:10'!
version0161: spec
	<version: '0.161' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.160 : have used a moValue: instead of a roValue:
0.161 : Removed the dependency with BlockContext'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/17/2012 09:10'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.175';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.28'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/17/2012 21:06'!
version0162: spec
	<version: '0.162' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.161 : Removed the dependency with BlockContext
0.162 : add a new layout, fixed some small lint issues (thanks Stef), added more example'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/17/2012 21:06'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.176';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.29'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/18/2012 10:05'!
version0163: spec
	<version: '0.163' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.162 : add a new layout, fixed some small lint issues (thanks Stef), added more example
0.163 : Added example for dynamic layout.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/18/2012 10:05'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.177';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.29'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/20/2012 19:22'!
version10: spec
	<version: '1.0' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '0.163 : Added example for dynamic layout.
1.0 : Fix in the choiceLayout example. Much nicer example.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/20/2012 19:22'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.178';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.31'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/21/2012 11:07'!
version1100: spec
	<version: '1.100' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.99 : Fixed Issue 136:	Roassal hover popup on edges
	http://code.google.com/p/moose-technology/issues/detail?id=826
1.100 : 
Fixed Issue 138:	Change the logo of ObjectProfile in Roassal Pharo
Fixed  Issue 137:	Integrating Dennis'' treeMapLayout in Roassal'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/21/2012 11:07'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.279';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.66'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/22/2012 19:58'!
version1101: spec
	<version: '1.101' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.100 : 
Fixed Issue 138:	Change the logo of ObjectProfile in Roassal Pharo
Fixed  Issue 137:	Integrating Dennis'' treeMapLayout in Roassal
1.101 : Issue 139:	Use of {} in some of the code'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/22/2012 19:58'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.280';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.66'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/23/2012 22:49'!
version1102: spec
	<version: '1.102' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.101 : Issue 139:	Use of {} in some of the code
1.102 : Fixes for VW'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/23/2012 22:49'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.281';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.66'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/23/2012 22:54'!
version1103: spec
	<version: '1.103' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.102 : Fixes for VW
1.103 : cleaning'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/23/2012 22:54'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.282';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.66'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/27/2012 10:06'!
version1104: spec
	<version: '1.104' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.103 : cleaning
1.104 : Fixed Issue 140:	TreeMap makes use of non existing methods in Pharo'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/27/2012 10:06'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.283';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.66'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/2/2012 00:38'!
version1105: spec
	<version: '1.105' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.104 : Fixed Issue 140:	TreeMap makes use of non existing methods in Pharo
1.105 : - all tests are green. Started to work on a menu widget.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/2/2012 00:38'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.285';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.67'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/2/2012 21:16'!
version1106: spec
	<version: '1.106' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.105 : - all tests are green. Started to work on a menu widget.
1.106 : Added ROAbstractElement>>on:doOnce: Useful for the menu'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/2/2012 21:16'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.286';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.67'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/4/2012 14:37'!
version1107: spec
	<version: '1.107' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.106 : Added ROAbstractElement>>on:doOnce: Useful for the menu
1.107 : small example for menu'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/4/2012 14:37'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.287';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.67'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/4/2012 15:31'!
version1108: spec
	<version: '1.108' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.107 : small example for menu
1.108 : Fixed Issue 141:	ROView>>add:
	Thanks Luc Fabresse and Noury Bouraqadi '.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/4/2012 15:31'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.288';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.67'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/5/2012 10:23'!
version1109: spec
	<version: '1.109' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.108 : Fixed Issue 141:	ROView>>add:
	Thanks Luc Fabresse and Noury Bouraqadi 
1.109 : Fixed Issue 830:	ROLabel dynamic text not updating bounds/ROBorder properly 
	Fixed Issue 142:	ROLabel dynamic text not updating bounds/ROBorder properly'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/5/2012 10:23'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.289';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.68'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/22/2012 14:04'!
version110: spec
	<version: '1.10' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.9 : Added a sortElementsWith: on ROAbstractView to reorder the nodes. Added a doPost: on ROLayout
1.10 : forgotten to implement doPost:'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/22/2012 14:04'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.187';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.35'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/9/2012 19:36'!
version1110: spec
	<version: '1.110' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.109 : Fixed Issue 830:	ROLabel dynamic text not updating bounds/ROBorder properly 
	Fixed Issue 142:	ROLabel dynamic text not updating bounds/ROBorder properly
1.110 : Doru''s fix for allElementsDo: and friends'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/9/2012 19:36'.
		spec 
			package: #Roassal with: 'Roassal-TudorGirba.292';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.68'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/9/2012 20:06'!
version1111: spec
	<version: '1.111' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.110 : Doru''s fix for allElementsDo: and friends
1.111 : Fixed Issue 148:	Roassal layouts do not properly take into account userDefinedEdges 
	http://code.google.com/p/moose-technology/issues/detail?id=834'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/9/2012 20:06'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.293';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.68'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/10/2012 10:02'!
version1112: spec
	<version: '1.112' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.111 : Fixed Issue 148:	Roassal layouts do not properly take into account userDefinedEdges 
	http://code.google.com/p/moose-technology/issues/detail?id=834
1.112 : Fixed Issue 149:	morph size. Thanks Doru for reporting the issue!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/10/2012 10:02'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.294';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.69'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/10/2012 10:12'!
version1113: spec
	<version: '1.113' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.112 : Fixed Issue 149:	morph size. Thanks Doru for reporting the issue!!
1.113 : added a new test for the bitmap size'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/10/2012 10:12'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.294';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.70'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/11/2012 09:05'!
version1114: spec
	<version: '1.114' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.113 : added a new test for the bitmap size
1.114 : Improvement of TreeMap. From Dennis Schenk: "This version includes more bugfixes and tests and an optimization: The layout doesn''t draw children of nodes if a certain minimum area per node is not available (the minimum area is configurable). This is for performance reasons.". Thanks a lot!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/11/2012 09:05'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.295';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.70'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/11/2012 16:03'!
version1115: spec
	<version: '1.115' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.114 : Improvement of TreeMap. From Dennis Schenk: "This version includes more bugfixes and tests and an optimization: The layout doesn''t draw children of nodes if a certain minimum area per node is not available (the minimum area is configurable). This is for performance reasons.". Thanks a lot!!
1.115 : Sync with VisualWorks'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/11/2012 16:03'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.296';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.71'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/11/2012 18:42'!
version1116: spec
	<version: '1.116' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.115 : Sync with VisualWorks
1.116 : Improvement of TreeMapLayout with the brightness.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/11/2012 18:42'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.297';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.71'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/14/2012 19:17'!
version1117: spec
	<version: '1.117' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.116 : Improvement of TreeMapLayout with the brightness.
1.117 : Fixed Issue 152:	Chaining the drawing of shapes '.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/14/2012 19:17'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.298';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/15/2012 11:03'!
version1118: spec
	<version: '1.118' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.117 : Fixed Issue 152:	Chaining the drawing of shapes 
1.118 : Fixed Issue 153:	Shrinking element'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/15/2012 11:03'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.299';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/15/2012 22:47'!
version1119: spec
	<version: '1.119' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.118 : Fixed Issue 153:	Shrinking element
1.119 : Enhancement of the treemap layout'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/15/2012 22:47'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.300';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/22/2012 17:54'!
version111: spec
	<version: '1.11' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.10 : forgotten to implement doPost:
1.11 : Added facilities to customize edge width'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/22/2012 17:54'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.188';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.35'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/16/2012 12:52'!
version1120: spec
	<version: '1.120' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.119 : Enhancement of the treemap layout
1.120 : Fixed Issue 154:	resize strategy for shrinking. Thanks Ben for the suggestion'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/16/2012 12:52'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.301';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/16/2012 14:20'!
version1121: spec
	<version: '1.121' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.120 : Fixed Issue 154:	resize strategy for shrinking. Thanks Ben for the suggestion
1.121 : Added TranslatingShape in the core
Fixed  Issue 155:	offset in a shape translation should be a block'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/16/2012 14:20'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.302';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/20/2012 10:02'!
version1122: spec
	<version: '1.122' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.121 : Added TranslatingShape in the core
Fixed  Issue 155:	offset in a shape translation should be a block
1.122 : Fix from Dennis about the TreeMapLayout'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/20/2012 10:02'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.303';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/20/2012 10:27'!
version1123: spec
	<version: '1.123' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.122 : Fix from Dennis about the TreeMapLayout
1.123 : Fixed  Issue 156:	ROPopup: Text not visible
	http://code.google.com/p/moose-technology/issues/detail?id=841'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/20/2012 10:27'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.304';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/20/2012 10:45'!
version1124: spec
	<version: '1.124' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.123 : Fixed  Issue 156:	ROPopup: Text not visible
	http://code.google.com/p/moose-technology/issues/detail?id=841
1.124 : Fixed Issue 157:	Duplication in ROAbstractArrow
http://code.google.com/p/objectprofile/issues/detail?id=157'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/20/2012 10:45'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.305';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/20/2012 12:14'!
version1125: spec
	<version: '1.125' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.124 : Fixed Issue 157:	Duplication in ROAbstractArrow
http://code.google.com/p/objectprofile/issues/detail?id=157
1.125 :
	Fixed Issue 158:	ROCenteredLabel 
	Fixed http://code.google.com/p/moose-technology/issues/detail?id=839'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/20/2012 12:14'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.306';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/20/2012 15:59'!
version1126: spec
	<version: '1.126' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.125 :
	Fixed Issue 158:	ROCenteredLabel 
	Fixed http://code.google.com/p/moose-technology/issues/detail?id=839
1.126 : minor fix'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/20/2012 15:59'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.307';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/21/2012 14:03'!
version1127: spec
	<version: '1.127' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.126 : minor fix
1.127 : Issue 159:	ROMenuElement class>>example has a bad ref'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/21/2012 14:03'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.308';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/23/2012 12:55'!
version1128: spec
	<version: '1.128' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.127 : Issue 159:	ROMenuElement class>>example has a bad ref
1.128 : Fixed  Issue 160:	The treemap examples do not work in VW, because of with:with:with:with:with:with:'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/23/2012 12:55'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.309';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/24/2012 11:17'!
version1129: spec
	<version: '1.129' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.128 : Fixed  Issue 160:	The treemap examples do not work in VW, because of with:with:with:with:with:with:
1.129 : Fixed Issue 163:	ROLightlyHighlightable drains element colour
	http://code.google.com/p/moose-technology/issues/detail?id=843
	Thanks Ben!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/24/2012 11:17'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.310';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/22/2012 19:02'!
version112: spec
	<version: '1.12' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.11 : Added facilities to customize edge width
1.12 : fixed a bug with withText:'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/22/2012 19:02'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.189';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.35'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/24/2012 12:16'!
version1130: spec
	<version: '1.130' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.129 : Fixed Issue 163:	ROLightlyHighlightable drains element colour
	http://code.google.com/p/moose-technology/issues/detail?id=843
	Thanks Ben!!
1.130 : Fixed Issue 162:	Menu buttons are transparent. Best is to have them with a white background'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/24/2012 12:16'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.311';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/26/2012 09:25'!
version1131: spec
	<version: '1.131' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.130 : Fixed Issue 162:	Menu buttons are transparent. Best is to have them with a white background
1.131 : Fixed Issue 164:	Children shape are not ending the chain shape anymore
	Fixed Issue 165:	Fix bug with the translate shape'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/26/2012 09:25'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.312';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/26/2012 11:19'!
version1132: spec
	<version: '1.132' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.131 : Fixed Issue 164:	Children shape are not ending the chain shape anymore
	Fixed Issue 165:	Fix bug with the translate shape
1.132 : Fixed Issue 166:	Non draggable view'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/26/2012 11:19'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.313';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/26/2012 19:13'!
version1133: spec
	<version: '1.133' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.132 : Fixed Issue 166:	Non draggable view
1.133 : Added a composite example in ROExample'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/26/2012 19:13'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.314';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/26/2012 19:45'!
version1134: spec
	<version: '1.134' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.133 : Added a composite example in ROExample
1.134 : Added a colroed system complexity in the mondrian example. Nice example of how to obtain color gradient.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/26/2012 19:45'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.315';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/28/2012 08:34'!
version1135: spec
	<version: '1.135' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.134 : Added a colroed system complexity in the mondrian example. Nice example of how to obtain color gradient.
1.135 : removed all work for the offset and translate shape'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/28/2012 08:34'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.316';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/28/2012 09:42'!
version1136: spec
	<version: '1.136' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.135 : removed all work for the offset and translate shape
1.136 : Fixed Issue 87:	method to rewrite'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/28/2012 09:42'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.317';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/28/2012 09:49'!
version1137: spec
	<version: '1.137' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.136 : Fixed Issue 87:	method to rewrite
1.137 : Fixed  Issue 126:	ROAbstractLine, ROLine'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/28/2012 09:49'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.318';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/28/2012 11:18'!
version1138: spec
	<version: '1.138' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.137 : Fixed  Issue 126:	ROAbstractLine, ROLine
1.138 : Cleaning'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/28/2012 11:18'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.319';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/28/2012 11:27'!
version1139: spec
	<version: '1.139' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.138 : Cleaning
1.139 : Fixed Issue 168:	linearFillColor:within: Mondrian builder does not operate with an empty list of elements'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/28/2012 11:27'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.320';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.72'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/22/2012 21:18'!
version113: spec
	<version: '1.13' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.12 : fixed a bug with withText:
1.13 : Removed unnecessary view classes'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/22/2012 21:18'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.190';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.36'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/29/2012 15:30'!
version1140: spec
	<version: '1.140' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.139 : Fixed Issue 168:	linearFillColor:within: Mondrian builder does not operate with an empty list of elements
1.140 : Fixed Issue 169:	Find button is not unlighted when clicking'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/29/2012 15:30'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.321';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.73'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 9/29/2012 16:22'!
version1141: spec
	<version: '1.141' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.140 : Fixed Issue 169:	Find button is not unlighted when clicking
1.141 : improved a test'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '9/29/2012 16:22'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.322';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.73'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/1/2012 09:35'!
version1142: spec
	<version: '1.142' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.141 : improved a test
1.142 : Fixed Issue 170:	Adding constraints on elements'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/1/2012 09:35'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.323';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.73'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/1/2012 09:39'!
version1143: spec
	<version: '1.143' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.142 : Fixed Issue 170:	Adding constraints on elements
1.143 : Fixed Issue 171:	Need of dominance and horizontal'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/1/2012 09:39'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.325';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.73'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/1/2012 09:45'!
version1144: spec
	<version: '1.144' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.143 : Fixed Issue 171:	Need of dominance and horizontal
1.144 : Fixed Issue 172:	Need for an example for layered horizontal tree layout'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/1/2012 09:45'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.326';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.73'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/1/2012 10:03'!
version1145: spec
	<version: '1.145' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.144 : Fixed Issue 172:	Need for an example for layered horizontal tree layout
1.145 : Fixed Issue 174:	Need to add an example for the constraints'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/1/2012 10:03'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.327';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.73'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/1/2012 13:50'!
version1146: spec
	<version: '1.146' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.145 : Fixed Issue 174:	Need to add an example for the constraints
1.146 : Fixed Issue 175:	Find does not work properly'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/1/2012 13:50'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.328';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.73'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/2/2012 09:35'!
version1147: spec
	<version: '1.147' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.146 : Fixed Issue 175:	Find does not work properly
1.147 : Sync with VisualWorks. Removed junk'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/2/2012 09:35'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.329';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.73'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/2/2012 16:32'!
version1148: spec
	<version: '1.148' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.147 : Sync with VisualWorks. Removed junk
1.148 : Fixed Issue 176:	ROPopup need to be improved'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/2/2012 16:32'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.330';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.73'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/2/2012 16:38'!
version1149: spec
	<version: '1.149' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.148 : Fixed Issue 176:	ROPopup need to be improved
1.149 : Fix by Dennis Schenk'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/2/2012 16:38'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.331';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.73'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/28/2012 21:28'!
version114: spec
	<version: '1.14' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.13 : Removed unnecessary view classes
1.14 : Severe bug about the offset of the popup fixed.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/28/2012 21:28'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.191';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.37'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/2/2012 19:58'!
version1150: spec
	<version: '1.150' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.149 : Fix by Dennis Schenk
1.150 : Fixed in Issue 177:	#attributes is not defined on ROAbstractElement'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/2/2012 19:58'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.332';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.73'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/2/2012 20:34'!
version1151: spec
	<version: '1.151' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.150 : Fixed in Issue 177:	#attributes is not defined on ROAbstractElement
1.151 : Fixed Issue 178:	accessing the element (and not the model) from a menu'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/2/2012 20:34'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.333';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/2/2012 20:43'!
version1152: spec
	<version: '1.152' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.151 : Fixed Issue 178:	accessing the element (and not the model) from a menu
1.152 : Fixed Issue 179:	ROEdge>>elementFromModel: does not exist'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/2/2012 20:43'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.334';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/3/2012 09:06'!
version1153: spec
	<version: '1.153' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.152 : Fixed Issue 179:	ROEdge>>elementFromModel: does not exist
1.153 : 
	Fixed  Issue 180:	Bug in an example
	Fixed Issue 181:	Need some animation example in ROExample'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/3/2012 09:06'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.335';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/3/2012 16:29'!
version1154: spec
	<version: '1.154' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.153 : 
	Fixed  Issue 180:	Bug in an example
	Fixed Issue 181:	Need some animation example in ROExample
1.154 : Fixed Issue 182:	ROCircle border only'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/3/2012 16:29'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.336';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/3/2012 19:02'!
version1155: spec
	<version: '1.155' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.154 : Fixed Issue 182:	ROCircle border only
1.155 : Fixed Issue 183:	Need an easy way to add and remove elements'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/3/2012 19:02'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.337';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/3/2012 19:11'!
version1156: spec
	<version: '1.156' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.155 : Fixed Issue 183:	Need an easy way to add and remove elements
1.156 : Added example about status bar'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/3/2012 19:11'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.338';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/3/2012 19:15'!
version1157: spec
	<version: '1.157' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.156 : Added example about status bar
1.157 : Making the tests green'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/3/2012 19:15'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.339';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/7/2012 13:11'!
version1158: spec
	<version: '1.158' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.157 : Making the tests green
1.158 : Fixed Issue 184:	Bug in the ExpandableNodesOn:'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/7/2012 13:11'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.340';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/7/2012 13:59'!
version1159: spec
	<version: '1.159' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.158 : Fixed Issue 184:	Bug in the ExpandableNodesOn:
1.159 : Added a small example about nesting layout using Roassal Core'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/7/2012 13:59'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.341';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/28/2012 23:04'!
version115: spec
	<version: '1.15' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.14 : Severe bug about the offset of the popup fixed.
1.15 : added a ROStackViewWithMenu to easily build visualization with menu'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/28/2012 23:04'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.192';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.37'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/7/2012 17:11'!
version1160: spec
	<version: '1.160' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.159 : Added a small example about nesting layout using Roassal Core
1.160 : Minor fix in the method complexity'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/7/2012 17:11'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.341';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/8/2012 09:01'!
version1161: spec
	<version: '1.161' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.160 : Minor fix in the method complexity
1.161 : Fixed Issue 186:	RubbedBand from ben'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/8/2012 09:01'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.342';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/8/2012 09:38'!
version1162: spec
	<version: '1.162' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.161 : Fixed Issue 186:	RubbedBand from ben
1.162 : Cleaning'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/8/2012 09:38'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.343';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/9/2012 08:53'!
version1163: spec
	<version: '1.163' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.162 : Cleaning
1.163 :  Issue 187:	Offset for shorterattachpoint
	Added the offset from Dennis. Thanks!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/9/2012 08:53'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.344';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/11/2012 13:16'!
version1164: spec
	<version: '1.164' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.163 :  Issue 187:	Offset for shorterattachpoint
	Added the offset from Dennis. Thanks!!
1.164 : Fixed  Issue 188:	cleaning of interaction key'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/11/2012 13:16'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.345';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/15/2012 10:18'!
version1165: spec
	<version: '1.165' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.164 : Fixed  Issue 188:	cleaning of interaction key
1.165 : Fixed  Issue 189:	Mondrian vs Roassal: a conceptual comparison
	Thanks Doru for spotting this problem'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/15/2012 10:18'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.346';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/15/2012 13:16'!
version1166: spec
	<version: '1.166' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.165 : Fixed  Issue 189:	Mondrian vs Roassal: a conceptual comparison
	Thanks Doru for spotting this problem
1.166 : Fixed Issue 190:	Example does not work in the easel'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/15/2012 13:16'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.351';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/15/2012 13:21'!
version1167: spec
	<version: '1.167' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.166 : Fixed Issue 190:	Example does not work in the easel
1.167 : comment in ROShape'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/15/2012 13:21'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.352';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/15/2012 20:17'!
version1168: spec
	<version: '1.168' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.167 : comment in ROShape
1.168 : Increased the tab conversion with a label.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/15/2012 20:17'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.353';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/15/2012 22:53'!
version1169: spec
	<version: '1.169' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.168 : Increased the tab conversion with a label.
1.169 : removing junk'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/15/2012 22:53'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.354';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/28/2012 23:35'!
version116: spec
	<version: '1.16' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.15 : added a ROStackViewWithMenu to easily build visualization with menu
1.16 : Removed a dependency to Pharo'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/28/2012 23:35'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.193';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.38'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/16/2012 14:19'!
version1170: spec
	<version: '1.170' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.169 : removing junk
1.170 : Small example from d3'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/16/2012 14:19'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.355';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/17/2012 08:35'!
version1171: spec
	<version: '1.171' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.170 : Small example from d3
1.171 :  Fixed Issue 192:	ROElement and ROAbstractElement. Thanks Doru for the suggestion'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/17/2012 08:35'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.356';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/17/2012 14:04'!
version1172: spec
	<version: '1.172' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.171 :  Fixed Issue 192:	ROElement and ROAbstractElement. Thanks Doru for the suggestion
1.172 : Fixed Issue 193:	Mondrian vs Roassal: a conceptual comparison'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/17/2012 14:04'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.357';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/17/2012 14:11'!
version1173: spec
	<version: '1.173' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.172 : Fixed Issue 193:	Mondrian vs Roassal: a conceptual comparison
1.173 : cleaning'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/17/2012 14:11'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.358';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.74'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/18/2012 09:16'!
version1174: spec
	<version: '1.174' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.173 : cleaning
1.174 : Issue 855:	Roassal Mondrian builder is not handling color based on the model
	
Issue 854:	Roassal Mondrian builder is not handling label based on model
Thanks Doru!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/18/2012 09:16'.
		spec 
			package: #Roassal with: 'Roassal-TudorGirba.359';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.75'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/18/2012 09:33'!
version1175: spec
	<version: '1.175' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.174 : Issue 855:	Roassal Mondrian builder is not handling color based on the model
	
Issue 854:	Roassal Mondrian builder is not handling label based on model
Thanks Doru!!
1.175 : minor changes in ROCenteredLabel>>drawOn:'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/18/2012 09:33'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.360';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.75'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/18/2012 09:37'!
version1176: spec
	<version: '1.176' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.175 : minor changes in ROCenteredLabel>>drawOn:
1.176 : cleaning'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/18/2012 09:37'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.361';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.75'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/18/2012 09:50'!
version1177: spec
	<version: '1.177' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.176 : cleaning
1.177 : Fixed Issue 194:	testLogHeight and testLogWidth uses isFloat'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/18/2012 09:50'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.362';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.75'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/18/2012 18:17'!
version1178: spec
	<version: '1.178' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.177 : Fixed Issue 194:	testLogHeight and testLogWidth uses isFloat
1.178 : Fixed Issue 195:	ROAbstractElement>>remove inconsistent nested
	http://code.google.com/p/moose-technology/issues/detail?id=856
	Thanks Ben for having spotted it!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/18/2012 18:17'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.363';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.75'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/20/2012 21:37'!
version1179: spec
	<version: '1.179' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.178 : Fixed Issue 195:	ROAbstractElement>>remove inconsistent nested
	http://code.google.com/p/moose-technology/issues/detail?id=856
	Thanks Ben for having spotted it!!
1.179 : Fixed Issue 197:	Circle do not compute the colors
	Fixed Issue 196:	Adding circle shape in the Mondrian builder'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/20/2012 21:37'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.364';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.75'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/29/2012 10:25'!
version117: spec
	<version: '1.17' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.16 : Removed a dependency to Pharo
1.17 : identified a bug with the label. Introduced the method preferedExtentsFor: Thanks Usman for finding it.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/29/2012 10:25'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.194';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.40'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/21/2012 11:44'!
version1180: spec
	<version: '1.180' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.179 : Fixed Issue 197:	Circle do not compute the colors
	Fixed Issue 196:	Adding circle shape in the Mondrian builder
1.180 : Cleaning ROMondrianBuilder. Removed two unused instance variables'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/21/2012 11:44'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.365';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.75'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/23/2012 09:02'!
version1181: spec
	<version: '1.181' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.180 : Cleaning ROMondrianBuilder. Removed two unused instance variables
1.181 : Fixed Issue 198:	borderWith: broken in Roassal?'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/23/2012 09:02'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.366';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.75'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 10/30/2012 11:52'!
version1182: spec
	<version: '1.182' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.181 : Fixed Issue 198:	borderWith: broken in Roassal?
1.182 : Fixed  Issue 199:	linearFillColor:within: does not work'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '10/30/2012 11:52'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.367';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.75'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 11/1/2012 12:14'!
version1183: spec
	<version: '1.183' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.182 : Fixed  Issue 199:	linearFillColor:within: does not work
1.183 : Fixed http://code.google.com/p/objectprofile/issues/detail?id=200'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '11/1/2012 12:14'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.368';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.76'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 11/1/2012 12:17'!
version1184: spec
	<version: '1.184' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.183 : Fixed http://code.google.com/p/objectprofile/issues/detail?id=200
1.184 : Minor comment of ROLineEndDiamond into RODiamond'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '11/1/2012 12:17'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.369';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.77'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 11/1/2012 15:34'!
version1185: spec
	<version: '1.185' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.184 : Minor comment of ROLineEndDiamond into RODiamond
1.185 : Fixed Issue 201:	Enh of TreeMapLayout'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '11/1/2012 15:34'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.370';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.77'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 11/3/2012 20:33'!
version1186: spec
	<version: '1.186' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.185 : Fixed Issue 201:	Enh of TreeMapLayout
1.186 : Minor fix'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '11/3/2012 20:33'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.371';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.77'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 11/14/2012 14:00'!
version1187: spec
	<version: '1.187' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.186 : Minor fix
1.187 : 
	Fixed Issue 206:	Camera and window size
	 Issue 205:	ROCamera>>height and height: are misleading names'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '11/14/2012 14:00'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.372';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.78'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 11/15/2012 14:14'!
version1188: spec
	<version: '1.188' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.187 : 
	Fixed Issue 206:	Camera and window size
	 Issue 205:	ROCamera>>height and height: are misleading names
1.188 : Issue 207:	Event when layout is executed'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '11/15/2012 14:14'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.373';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.78'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 11/15/2012 16:38'!
version1189: spec
	<version: '1.189' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.188 : Issue 207:	Event when layout is executed
1.189 : Fixed Issue 208:	New constraints about sticking an element at the bottom of the window'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '11/15/2012 16:38'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.374';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.78'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/1/2012 10:29'!
version118: spec
	<version: '1.18' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.17 : identified a bug with the label. Introduced the method preferedExtentsFor: Thanks Usman for finding it.
1.18 : Fixed issue #64: 	Add a new attach point with shorter edge'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/1/2012 10:29'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.195';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.40'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 11/15/2012 16:51'!
version1190: spec
	<version: '1.190' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.189 : Fixed Issue 208:	New constraints about sticking an element at the bottom of the window
1.190 : Fixed Issue 209:	Update example with constraints for the status bar'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '11/15/2012 16:51'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.375';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.78'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 11/16/2012 09:33'!
version1191: spec
	<version: '1.191' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.190 : Fixed Issue 209:	Update example with constraints for the status bar
1.191 : Fixed Issue 102:	add progress bar in the layout'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '11/16/2012 09:33'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.376';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.79'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 11/19/2012 15:16'!
version1192: spec
	<version: '1.192' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.191 : Fixed Issue 102:	add progress bar in the layout
1.192 : Fixed  Issue 210:	add focus on bottom left'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '11/19/2012 15:16'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.377';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.79'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 11/19/2012 15:36'!
version1193: spec
	<version: '1.193' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.192 : Fixed  Issue 210:	add focus on bottom left
1.193 : Fixed Issue 211:	focus on does not take into account the size of the window'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '11/19/2012 15:36'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.378';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.79'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 11/21/2012 09:12'!
version1194: spec
	<version: '1.194' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.193 : Fixed Issue 211:	focus on does not take into account the size of the window
1.194 : Increased a bit the coverage'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '11/21/2012 09:12'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.379';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.79'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 11/21/2012 14:26'!
version1195: spec
	<version: '1.195' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.194 : Increased a bit the coverage
1.195 : Fixed Issue 212:	Focus on in Roassal'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '11/21/2012 14:26'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.380';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.79'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 11/21/2012 14:37'!
version1196: spec
	<version: '1.196' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.195 : Fixed Issue 212:	Focus on in Roassal
1.196 : missing update'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '11/21/2012 14:37'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.381';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.79'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 11/25/2012 11:07'!
version1197: spec
	<version: '1.197' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.196 : missing update
1.197 : Fixed Issue 213:	on:doOnce: is buggy'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '11/25/2012 11:07'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.382';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.80'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 11/25/2012 11:42'!
version1198: spec
	<version: '1.198' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.197 : Fixed Issue 213:	on:doOnce: is buggy
1.198 : Fixed http://code.google.com/p/moose-technology/issues/detail?id=872'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '11/25/2012 11:42'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.383';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.80'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 11/27/2012 19:45'!
version1199: spec
	<version: '1.199' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.198 : Fixed http://code.google.com/p/moose-technology/issues/detail?id=872
1.199 : Fixed Issue 215:	ROElement>>accept:'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '11/27/2012 19:45'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.384';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.80'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/1/2012 15:06'!
version119: spec
	<version: '1.19' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.18 : Fixed issue #64: 	Add a new attach point with shorter edge
1.19 : Added ROButtonElement'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/1/2012 15:06'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.196';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.40'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/20/2012 19:49'!
version11: spec
	<version: '1.1' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.0 : Fix in the choiceLayout example. Much nicer example.
1.1 : Minor fix in ROExample. A test has been moved to platform specific since it has a reference to PackagesInfo'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/20/2012 19:49'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.179';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.32'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 11/27/2012 20:12'!
version1200: spec
	<version: '1.200' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.199 : Fixed Issue 215:	ROElement>>accept:
1.200 : Fixed  Issue 216:	ROHighlighter is buggy
	Thanks simon for finding this error!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '11/27/2012 20:12'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.385';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.80'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 11/30/2012 16:20'!
version1201: spec
	<version: '1.201' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.200 : Fixed  Issue 216:	ROHighlighter is buggy
	Thanks simon for finding this error!!
1.201 : Fixed Issue 217:	Builder and opening with a particular size'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '11/30/2012 16:20'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.386';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.81'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 11/30/2012 17:07'!
version1202: spec
	<version: '1.202' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.201 : Fixed Issue 217:	Builder and opening with a particular size
1.202 : Fixed Issue 219:	Thanks Emmanuel in the info of Roassal easel'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '11/30/2012 17:07'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.386';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.82'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/1/2012 11:19'!
version1203: spec
	<version: '1.203' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.202 : Fixed Issue 219:	Thanks Emmanuel in the info of Roassal easel
1.203 : Fixed Issue 221:	ROExample>>motionOn: should allow for a reset
	Started to work on Issue 220'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/1/2012 11:19'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.387';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.82'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/1/2012 17:05'!
version1204: spec
	<version: '1.204' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.203 : Fixed Issue 221:	ROExample>>motionOn: should allow for a reset
	Started to work on Issue 220
1.204 : Fixed Issue 223:	Animation in Roassal'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/1/2012 17:05'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.388';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.83'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/1/2012 17:09'!
version1205: spec
	<version: '1.205' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.204 : Fixed Issue 223:	Animation in Roassal
1.205 : Fixed  Issue 222:	What should we do with ROBegginingAnimation?
	Removed ROBegginingAnimation'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/1/2012 17:09'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.389';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.84'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/1/2012 17:52'!
version1206: spec
	<version: '1.206' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.205 : Fixed  Issue 222:	What should we do with ROBegginingAnimation?
	Removed ROBegginingAnimation
1.206 : Sync with VisualWorks'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/1/2012 17:52'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.390';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.84'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/1/2012 21:45'!
version1207: spec
	<version: '1.207' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.206 : Sync with VisualWorks
1.207 : Added animation example'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/1/2012 21:45'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.391';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.84'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'VanessaPena 12/2/2012 19:21'!
version1208: spec
	<version: '1.208' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.207 : Added animation example
1.208 : Merged version'.
		spec author: 'VanessaPena'.
		spec timestamp: '12/2/2012 19:21'.
		spec 
			package: #Roassal with: 'Roassal-VanessaPena.394';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.86'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'VanessaPena 12/2/2012 20:01'!
version1209: spec
	<version: '1.209' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.208 : Merged version
1.209 : now all the tests are green'.
		spec author: 'VanessaPena'.
		spec timestamp: '12/2/2012 20:01'.
		spec 
			package: #Roassal with: 'Roassal-VanessaPena.394';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.88'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/1/2012 18:07'!
version120: spec
	<version: '1.20' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.19 : Added ROButtonElement
1.20 : Added ROButtonElement and moved the Roassel easel in the Tools menu.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/1/2012 18:07'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.197';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.41'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/4/2012 09:07'!
version1210: spec
	<version: '1.210' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.209 : now all the tests are green
1.210 : Fixed  Issue 224:	zIndex and Merge with the code of Vanessa. Exporter are now in!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/4/2012 09:07'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.395';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.89'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/4/2012 10:11'!
version1211: spec
	<version: '1.211' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.210 : Fixed  Issue 224:	zIndex and Merge with the code of Vanessa. Exporter are now in!!
1.211 : Minor cleaning'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/4/2012 10:11'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.396';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.89'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/4/2012 14:02'!
version1212: spec
	<version: '1.212' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.211 : Minor cleaning
1.212 : Minor fix in the html exporter'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/4/2012 14:02'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.397';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.89'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/5/2012 10:40'!
version1213: spec
	<version: '1.213' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.212 : Minor fix in the html exporter
1.213 : Fixed Issue 225:	MondrianViewBuilder should support a better zOrder
	http://code.google.com/p/moose-technology/issues/detail?id=888'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/5/2012 10:40'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.398';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.90'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/5/2012 18:05'!
version1214: spec
	<version: '1.214' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.213 : Fixed Issue 225:	MondrianViewBuilder should support a better zOrder
	http://code.google.com/p/moose-technology/issues/detail?id=888
1.214 : Fixed Issue 226:	elementFromModel: can return an edge'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/5/2012 18:05'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.399';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.90'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/5/2012 18:19'!
version1215: spec
	<version: '1.215' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.214 : Fixed Issue 226:	elementFromModel: can return an edge
1.215 : Merged with version of Vanessa'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/5/2012 18:19'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.400';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.90'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/5/2012 18:32'!
version1216: spec
	<version: '1.216' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.215 : Merged with version of Vanessa
1.216 : Fixed Issue 227:	The ROAddName example does not work properly'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/5/2012 18:32'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.401';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.90'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/6/2012 17:35'!
version1217: spec
	<version: '1.217' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.216 : Fixed Issue 227:	The ROAddName example does not work properly
1.217 : Fixed Issue 228:	edges and elementAt:'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/6/2012 17:35'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.402';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.91'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'VanessaPena 12/6/2012 23:57'!
version1218: spec
	<version: '1.218' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.217 : Fixed Issue 228:	edges and elementAt:
1.218 : Merges with Alex version. Added serializer exporters (save and load). 
-FIxed problems with position of elements in PNG and HTML exporters.
- Extraxt extra files in the right directory'.
		spec author: 'VanessaPena'.
		spec timestamp: '12/6/2012 23:57'.
		spec 
			package: #Roassal with: 'Roassal-VanessaPena.403';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.92'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/8/2012 14:31'!
version1219: spec
	<version: '1.219' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.218 : Merges with Alex version. Added serializer exporters (save and load). 
-FIxed problems with position of elements in PNG and HTML exporters.
- Extraxt extra files in the right directory
1.220 :  Issue 229:	transcript show in ROMorph'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/8/2012 14:31'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.404';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.94'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/2/2012 10:06'!
version121: spec
	<version: '1.21' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.20 : Added ROButtonElement and moved the Roassel easel in the Tools menu.
1.21 : Fixed ISSUE #61: Zooming in and out preserve the size of the popup. The zoom button can now be added to Hapao and Kai in VW. All tests are green'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/2/2012 10:06'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.198';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.42'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'VanessaPena 12/7/2012 01:38'!
version1220: spec
	<version: '1.220' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.220 : Added dependencies with Fuel for the exporters'.
		spec author: 'VanessaPena'.
		spec 
			package: #Roassal with: 'Roassal-VanessaPena.403';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.93'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/11/2012 15:13'!
version1221: spec
	<version: '1.221' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.220 :  Issue 229:	transcript show in ROMorph
1.221 : large internal change: 
- Fixed Issue 232:	ROVIew should be the only one to have a zOrdering
- Fixed Issue 231:	Adding a tracing canvas'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/11/2012 15:13'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.405';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.95'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/11/2012 19:25'!
version1222: spec
	<version: '1.222' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.221 : large internal change: 
- Fixed Issue 232:	ROVIew should be the only one to have a zOrdering
- Fixed Issue 231:	Adding a tracing canvas
1.222 : Caching height, width, color
Fixed Issue 235:	Method complexity does not work'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/11/2012 19:25'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.406';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.95'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/11/2012 19:29'!
version1223: spec
	<version: '1.223' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.222 : Caching height, width, color
Fixed Issue 235:	Method complexity does not work
1.223 : Fixed Issue 236:	unecessary extentCache in ROElement'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/11/2012 19:29'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.407';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.95'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/11/2012 20:33'!
version1224: spec
	<version: '1.224' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.223 : Fixed Issue 236:	unecessary extentCache in ROElement
1.224 : Fixed Issue 237:	outer instead of outer
	Thanks Ben!!!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/11/2012 20:33'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.408';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.95'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/11/2012 20:47'!
version1225: spec
	<version: '1.225' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.224 : Fixed Issue 237:	outer instead of outer
	Thanks Ben!!!!
1.225 : Fixed Issue 238:	Need a way to resend the event to the parent'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/11/2012 20:47'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.409';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.95'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/11/2012 20:53'!
version1226: spec
	<version: '1.226' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.225 : Fixed Issue 238:	Need a way to resend the event to the parent
1.226 : fixed yellow test'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/11/2012 20:53'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.410';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.95'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/11/2012 21:13'!
version1227: spec
	<version: '1.227' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.226 : fixed yellow test
1.227 : Fixed Issue 239:	zOrdering'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/11/2012 21:13'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.411';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.95'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/13/2012 11:49'!
version1228: spec
	<version: '1.228' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.227 : Fixed Issue 239:	zOrdering
1.228 : Fixed Issue 242:	Need a comment for ROContainer>>remove:'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/13/2012 11:49'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.412';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.95'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/13/2012 12:21'!
version1229: spec
	<version: '1.229' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.228 : Fixed Issue 242:	Need a comment for ROContainer>>remove:
1.229 : using maxValue: instead of max'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/13/2012 12:21'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.413';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.96'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/2/2012 14:19'!
version122: spec
	<version: '1.22' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.21 : Fixed ISSUE #61: Zooming in and out preserve the size of the popup. The zoom button can now be added to Hapao and Kai in VW. All tests are green
1.22 : code cleaning'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/2/2012 14:19'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.199';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.42'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/13/2012 12:31'!
version1230: spec
	<version: '1.230' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.229 : using maxValue: instead of max
1.230 : Fixed Issue 243:	ROExample>>bouncingBallOn: does not work'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/13/2012 12:31'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.414';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.96'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/13/2012 13:10'!
version1231: spec
	<version: '1.231' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.230 : Fixed Issue 243:	ROExample>>bouncingBallOn: does not work
1.231 : 
	Fixed Issue 246:	Tracing does not work with ROCircle
	Fixed Issue 245:	need a reset of ROView.NullView'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/13/2012 13:10'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.415';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.96'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/13/2012 15:21'!
version1232: spec
	<version: '1.232' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.231 : 
	Fixed Issue 246:	Tracing does not work with ROCircle
	Fixed Issue 245:	need a reset of ROView.NullView
1.232 : Fixed Issue 244:	ROExample>>recursionProcessingOn: does not work'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/13/2012 15:21'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.416';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.96'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/13/2012 15:48'!
version1233: spec
	<version: '1.233' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.232 : Fixed Issue 244:	ROExample>>recursionProcessingOn: does not work
1.233 : Fixed Issue 247:	The info in the easel does not work'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/13/2012 15:48'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.417';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.96'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/13/2012 17:47'!
version1234: spec
	<version: '1.234' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.233 : Fixed Issue 247:	The info in the easel does not work
1.234 : Added Space invader example'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/13/2012 17:47'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.418';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.96'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/13/2012 17:54'!
version1235: spec
	<version: '1.235' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.234 : Added Space invader example
1.235 : Fixed Issue 230:	The children hierarchy should be removed...'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/13/2012 17:54'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.419';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.96'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/13/2012 18:00'!
version1236: spec
	<version: '1.236' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.235 : Fixed Issue 230:	The children hierarchy should be removed...
1.236 : Improvement of ROSelection by Ben.
http://code.google.com/p/moose-technology/issues/detail?id=894'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/13/2012 18:00'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.420';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.96'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/13/2012 18:18'!
version1237: spec
	<version: '1.237' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.236 : Improvement of ROSelection by Ben.
http://code.google.com/p/moose-technology/issues/detail?id=894
1.237 : Fixed Issue 248:	change name from ROZOrdering>>at:put: to setZIndex:if:'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/13/2012 18:18'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.421';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.96'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/14/2012 13:50'!
version1238: spec
	<version: '1.238' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.237 : Fixed Issue 248:	change name from ROZOrdering>>at:put: to setZIndex:if:
1.238 : Sync with VW'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/14/2012 13:50'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.422';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.96'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/14/2012 13:55'!
version1239: spec
	<version: '1.239' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.238 : Sync with VW
1.239 : utils for substrings in ROTracingCanvas'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/14/2012 13:55'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.423';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.96'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/2/2012 14:29'!
version123: spec
	<version: '1.23' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.22 : code cleaning
1.23 : Fixed Issue 50:	Variable rename in Roassal'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/2/2012 14:29'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.200';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.42'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/14/2012 13:59'!
version1240: spec
	<version: '1.240' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.239 : utils for substrings in ROTracingCanvas
1.240 : missing substrings'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/14/2012 13:59'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.424';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.96'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/14/2012 14:12'!
version1241: spec
	<version: '1.241' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.240 : missing substrings
1.241 : VW Sync'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/14/2012 14:12'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.425';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.96'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/14/2012 16:31'!
version1242: spec
	<version: '1.242' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.241 : VW Sync
1.242 : yellow test that is turned green'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/14/2012 16:31'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.426';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.96'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/16/2012 18:38'!
version1243: spec
	<version: '1.243' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.242 : yellow test that is turned green
1.243 : improved ROMouseClick events. Thanks Ben!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/16/2012 18:38'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.427';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.97'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/17/2012 21:34'!
version1244: spec
	<version: '1.244' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.243 : improved ROMouseClick events. Thanks Ben!!
1.244 : Fixed Issue 249:	item:action: is buggy. The block argument should expect a model, and not a ROElement'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/17/2012 21:34'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.428';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.97'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/18/2012 15:42'!
version1245: spec
	<version: '1.245' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.244 : Fixed Issue 249:	item:action: is buggy. The block argument should expect a model, and not a ROElement
1.245 : Fixed Issue 250:	Need ROConstraint>>stickToTopRight:'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/18/2012 15:42'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.429';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.97'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/19/2012 10:14'!
version1246: spec
	<version: '1.246' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.245 : Fixed Issue 250:	Need ROConstraint>>stickToTopRight:
1.246 : 
	- Fixed Issue 234:	TreeMap tests are yellow
	- Fixed  Issue 251:	Fuel tests are yellow!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/19/2012 10:14'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.430';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.98'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 12/19/2012 10:30'!
version1247: spec
	<version: '1.247' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.246 : 
	- Fixed Issue 234:	TreeMap tests are yellow
	- Fixed  Issue 251:	Fuel tests are yellow!!
1.247 : Fixed Issue 252:	Serializer tests are yellow in Pharo 2.0'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '12/19/2012 10:30'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.430';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.99'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 1/2/2013 09:22'!
version1248: spec
	<version: '1.248' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.247 : Fixed Issue 252:	Serializer tests are yellow in Pharo 2.0
1.248 : Fixed Issue 257:	ROPopup should remain in-view when opened on element in bottom right of pane
	thanks ben for having notificed this problem!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '1/2/2013 09:22'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.438';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.102'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 1/1/2013 17:03'!
version1249: spec
	<version: '1.249' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.249 : Included Minimap and last changes from Vanessa'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '1/1/2013 13:06'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.437';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.102'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/2/2012 17:21'!
version124: spec
	<version: '1.24' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.23 : Fixed Issue 50:	Variable rename in Roassal
1.24 : Added a small accessor to stack in the builder'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/2/2012 17:21'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.201';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.42'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 1/2/2013 16:10'!
version1250: spec
	<version: '1.250' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.248 : Fixed Issue 257:	ROPopup should remain in-view when opened on element in bottom right of pane
	thanks ben for having notificed this problem!!
1.250 : added sortedAs: 
'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '1/2/2013 16:10'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.439';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.102'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'VanessaPena 1/3/2013 17:51'!
version1251: spec
	<version: '1.251' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.250 : added sortedAs: 

1.251 : updating the configuration'.
		spec author: 'VanessaPena'.
		spec timestamp: '1/3/2013 17:51'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-VanessaPena.441';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.104'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'VanessaPena 1/3/2013 18:11'!
version1252: spec
	<version: '1.252' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.251 : updating the configuration
1.252 : Rename ROViewMiniMap to ROMiniMap'.
		spec author: 'VanessaPena'.
		spec timestamp: '1/3/2013 18:11'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-VanessaPena.442';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.104'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 1/10/2013 11:02'!
version1253: spec
	<version: '1.253' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.252 : Rename ROViewMiniMap to ROMiniMap
1.253 : Including semantic zooming + bug fixes'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '1/10/2013 11:02'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.451';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.104'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'VanessaPena 1/10/2013 15:02'!
version1254: spec
	<version: '1.254' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.253 : Including semantic zooming + bug fixes
1.254 : deleted a space for Pablo :)'.
		spec author: 'VanessaPena'.
		spec timestamp: '1/10/2013 15:02'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-VanessaPena.452';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.104'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'VanessaPena 1/11/2013 15:40'!
version1255: spec
	<version: '1.255' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.254 : deleted a space for Pablo :)
1.255 : Added ROValueLinearNormalizer and the corresponding test.'.
		spec author: 'VanessaPena'.
		spec timestamp: '1/11/2013 15:40'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlejandroInfante.453';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.104'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 1/14/2013 12:08'!
version1256: spec
	<version: '1.256' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.255 : Added ROValueLinearNormalizer and the corresponding test.
1.256 : Fixed  Issue 268:	BlockClosure>>roValue: should be moved to the platform specific package'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '1/14/2013 12:08'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.455';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.105'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 1/14/2013 12:18'!
version1257: spec
	<version: '1.257' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.256 : Fixed  Issue 268:	BlockClosure>>roValue: should be moved to the platform specific package
1.257 : Merged with previous version'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '1/14/2013 12:18'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.456';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.105'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 1/14/2013 12:28'!
version1258: spec
	<version: '1.258' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.257 : Merged with previous version
1.258 : Removed the Roassal class junk'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '1/14/2013 12:28'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.457';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.105'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'VanessaPena 1/16/2013 10:22'!
version1259: spec
	<version: '1.259' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.258 : Removed the Roassal class junk
1.259 : bug fix by Daniel Aviv'.
		spec author: 'VanessaPena'.
		spec timestamp: '1/16/2013 10:22'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-VanessaPena.458';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.105'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/2/2012 17:52'!
version125: spec
	<version: '1.25' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.24 : Added a small accessor to stack in the builder
1.25 : Bug in popupView:delay: fixed'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/2/2012 17:52'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.202';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.42'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'VanessaPena 1/17/2013 16:00'!
version1260: spec
	<version: '1.260' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.259 : bug fix by Daniel Aviv
1.260 : added a semantic zoom example + remove platform exporter from morphic'.
		spec author: 'VanessaPena'.
		spec timestamp: '1/17/2013 16:00'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-VanessaPena.461';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.107'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'VanessaPena 1/17/2013 18:30'!
version1261: spec
	<version: '1.261' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.260 : added a semantic zoom example + remove platform exporter from morphic
1.261 : better example of polymetric semantic zoom'.
		spec author: 'VanessaPena'.
		spec timestamp: '1/17/2013 18:30'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-VanessaPena.462';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.107'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 1/18/2013 14:07'!
version1262: spec
	<version: '1.262' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.261 : better example of polymetric semantic zoom
1.262 : Fixed Issue 270:	ROEvent, ROLayoutEvent, ROWindowResized'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '1/18/2013 14:07'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.463';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.107'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 1/18/2013 15:24'!
version1263: spec
	<version: '1.263' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.262 : Fixed Issue 270:	ROEvent, ROLayoutEvent, ROWindowResized
1.263 : Fixed Issue 271:	Roassal is not compliant to the VisualAge syntax'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '1/18/2013 15:24'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.464';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.107'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 1/26/2013 18:52'!
version1264: spec
	<version: '1.264' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.263 : Fixed Issue 271:	Roassal is not compliant to the VisualAge syntax
1.264 : Fixed Issue 272:	Improvement needed of ROCircleLayout
1.264 : Adding the use of the tracing canvas in the failing test related to tree layout.
Added fix from David regarding the port to VA Smalltalk'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '1/26/2013 18:52'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.467';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.109'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 1/24/2013 15:17'!
version1265: spec
	<version: '1.265' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.264 : Fixed Issue 272:	Improvement needed of ROCircleLayout
1.265 : More things to make it compatible with VASmalltalk'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '1/24/2013 15:17'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.466';
			package: #RoassalMorphic with: 'RoassalMorphic-DR.108'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 1/24/2013 15:55'!
version1266: spec
	<version: '1.266' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.265 : More things to make it compatible with VASmalltalk'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '1/24/2013 15:55'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.466';
			package: #RoassalMorphic with: 'RoassalMorphic-DR.108'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 1/26/2013 19:19'!
version1267: spec
	<version: '1.267' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.264 : Adding the use of the tracing canvas in the failing test related to tree layout.
Added fix from David regarding the port to VA Smalltalk
1.267 : Fixed Issue 274:	Issue 903:	ROEdge without ROLine locks the image'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '1/26/2013 19:19'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.468';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.109'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'VanessaPena 1/28/2013 15:47'!
version1268: spec
	<version: '1.268' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.267 : Fixed Issue 274:	Issue 903:	ROEdge without ROLine locks the image
1.268 : Fixed a little bug with setting different height and width'.
		spec author: 'VanessaPena'.
		spec timestamp: '1/28/2013 15:47'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-VanessaPena.469';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.109'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 1/30/2013 10:37'!
version1269: spec
	<version: '1.269' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.268 : Fixed a little bug with setting different height and width
1.269 : removing use of character to cope with Amber''s constraints'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '1/30/2013 10:37'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.470';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.109'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/3/2012 14:54'!
version126: spec
	<version: '1.26' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.25 : Bug in popupView:delay: fixed
1.26 :'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/3/2012 14:54'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.203';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.43'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 1/30/2013 12:07'!
version1270: spec
	<version: '1.270' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.269 : removing use of character to cope with Amber''s constraints
1.270 : Removing use of Character and $X syntax'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '1/30/2013 12:07'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.471';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.109'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 1/30/2013 12:13'!
version1271: spec
	<version: '1.271' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.270 : Removing use of Character and $X syntax
1.271 : Transforming #(foo) => #(#foo)  Useful for porting to Amber'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '1/30/2013 12:13'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.472';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.109'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 1/31/2013 16:59'!
version1272: spec
	<version: '1.272' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.271 : Transforming #(foo) => #(#foo)  Useful for porting to Amber
1.272 : All events are now subclass of ROEvent'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '1/31/2013 16:59'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.473';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.109'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'VanessaPena 1/31/2013 18:55'!
version1273: spec
	<version: '1.273' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.272 : All events are now subclass of ROEvent
1.273 : 
- clean the exporters code
- allow the exporters to work with 2.0'.
		spec author: 'VanessaPena'.
		spec timestamp: '1/31/2013 18:55'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-VanessaPena.475';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.111'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 2/23/2013 20:13'!
version1274: spec
	<version: '1.274' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.273 : 
- clean the exporters code
- allow the exporters to work with 2.0
1.274 : Fixed Having ROView>>removeAllElementsToRender
Thanks Dennis for this suggestion'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '2/23/2013 20:13'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.476';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.111'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 3/6/2013 11:20'!
version1275: spec
	<version: '1.275' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.274 : Fixed Having ROView>>removeAllElementsToRender
Thanks Dennis for this suggestion
1.275 : Fixed Issue 281:	Enhancement of the tree map Layout
	Thanks Dennis!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '3/6/2013 11:20'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.477';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.111'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 3/6/2013 11:35'!
version1276: spec
	<version: '1.276' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.275 : Fixed Issue 281:	Enhancement of the tree map Layout
	Thanks Dennis!!
1.276 : Fixed Issue 283:	Element Based z-Ordering
I made ROBasicZOrdering superclass of ROZOrdering.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '3/6/2013 11:35'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.478';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.111'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 3/6/2013 15:14'!
version1277: spec
	<version: '1.277' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.276 : Fixed Issue 283:	Element Based z-Ordering
I made ROBasicZOrdering superclass of ROZOrdering.
1.277 : Added a class comment in ROView'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '3/6/2013 15:14'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.479';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.111'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 3/6/2013 15:40'!
version1278: spec
	<version: '1.278' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.277 : Added a class comment in ROView
1.278 : Refactored a bit the label hiearchy'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '3/6/2013 15:40'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.480';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.111'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 3/6/2013 16:15'!
version1279: spec
	<version: '1.279' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.278 : Refactored a bit the label hiearchy
1.279 : 
	Fixed Issue 288:	Reversed arrow should be available
	Fixed Issue 287:	Add an example about temporary edges
	Fixed Issue 286:	haltOnce in #addingNameOn:'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '3/6/2013 16:15'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.481';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.111'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/3/2012 15:25'!
version127: spec
	<version: '1.27' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.26 :
1.27 : Minor fix to make VW happy'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/3/2012 15:25'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.204';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.43'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 3/6/2013 16:30'!
version1280: spec
	<version: '1.280' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.279 : 
	Fixed Issue 288:	Reversed arrow should be available
	Fixed Issue 287:	Add an example about temporary edges
	Fixed Issue 286:	haltOnce in #addingNameOn:
1.280 : Fixed Issue 289:	Optimization of the tree map layout
	thanks Dennis!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '3/6/2013 16:30'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.482';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.111'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'VanessaPena 3/7/2013 11:47'!
version1281: spec
	<version: '1.281' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.280 : Fixed Issue 289:	Optimization of the tree map layout
	thanks Dennis!!
1.281 : Old configuration corrupted. Putting everything in order with Versionner'.
		spec author: 'VanessaPena'.
		spec timestamp: '3/7/2013 11:47'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-VanessaPena.484';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.111'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 3/11/2013 11:42'!
version1282: spec
	<version: '1.282' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.281 : Old configuration corrupted. Putting everything in order with Versionner
1.282 : Minor fix, cleaning. Adding comments'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '3/11/2013 11:42'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.485';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.111'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'VanessaPena 3/12/2013 18:24'!
version1283: spec
	<version: '1.283' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.282 : Minor fix, cleaning. Adding comments
1.283 :

Object Profile issue 298
Moose issue 857 fixed'.
		spec author: 'VanessaPena'.
		spec timestamp: '3/12/2013 18:24'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-VanessaPena.486';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.112'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'VanessaPena 3/14/2013 17:34'!
version1284: spec
	<version: '1.284' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.283 :

Object Profile issue 298
Moose issue 857 fixed
1.284 : Added ROConstraint >> stick:onTheCenterOf: '.
		spec author: 'VanessaPena'.
		spec timestamp: '3/14/2013 17:34'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-VanessaPena.487';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.113'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'VanessaPena 3/15/2013 12:17'!
version1285: spec
	<version: '1.285' imports: #('0.3-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.284 : Added ROConstraint >> stick:onTheCenterOf: 
1.285 : updating the configuration without loading Fuel'.
		spec author: 'VanessaPena'.
		spec timestamp: '3/15/2013 12:17'.
		spec project: 'Fuel Core' with: '1.8.1'.
		spec 
			package: #Roassal with: 'Roassal-VanessaPena.487';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.114'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'VanessaPena 3/15/2013 12:18'!
version1286: spec
	<version: '1.286' imports: #('0.4-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.285 : updating the configuration without loading Fuel'.
		spec author: 'VanessaPena'.
		spec timestamp: '3/15/2013 12:18'.
		spec 
			package: #Roassal with: 'Roassal-VanessaPena.487';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.114'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 3/20/2013 09:52'!
version1287: spec
	<version: '1.287' imports: #('0.4-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.287: Fixed Issue 303:	ifNil:ifNotNil: should not be used
1.287 : Merged with Doru''s version
Name: Roassal-TudorGirba.489
Author: TudorGirba
Time: 19 March 2013, 9:35:29.831 pm
UUID: 7951a91b-1ac2-4a9a-800a-aab79e8c7a20
Ancestors: Roassal-TudorGirba.488

removed a treemap test that depended on the amount of collection subclasses. The assertions of this test are already covered in another test that works with plain numbers.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '3/20/2013 09:52'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.490';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.114'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 3/20/2013 10:31'!
version1288: spec
	<version: '1.288' imports: #('0.4-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.287 : Merged with Doru''s version
Name: Roassal-TudorGirba.489
Author: TudorGirba
Time: 19 March 2013, 9:35:29.831 pm
UUID: 7951a91b-1ac2-4a9a-800a-aab79e8c7a20
Ancestors: Roassal-TudorGirba.488

removed a treemap test that depended on the amount of collection subclasses. The assertions of this test are already covered in another test that works with plain numbers.
1.288 : Fixed Issue 304:	Pb with ROBasicZOrdering
	Thanks Dennis Schenk!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '3/20/2013 10:31'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.491';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.114'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 3/25/2013 10:53'!
version1289: spec
	<version: '1.289' imports: #('0.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.288 : Fixed Issue 304:	Pb with ROBasicZOrdering
	Thanks Dennis Schenk!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '3/20/2013 10:32'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.491';
			package: #RoassalMorphic with: 'RoassalMorphic-VanessaPena.114'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/3/2012 15:45'!
version128: spec
	<version: '1.28' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.27 : Minor fix to make VW happy
1.28 : Fixe  Issue 21:	PopupView in ROMondrianViewBuilder in VW not working correctly'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/3/2012 15:45'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.205';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.43'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 3/31/2013 09:00'!
version1290: spec
	<version: '1.290' imports: #('0.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.289 : cleaning and refactoring'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '3/31/2013 09:00'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.491';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.115'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 3/31/2013 11:36'!
version1291: spec
	<version: '1.291' imports: #('0.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.290 : - Correctly implemented layout start, step and end announcement support.
- Fixed a bug related to layout creation.

Thanks Dennis Schenk!!
1.291 : Improvement of the force based layout. Thanks Dennis!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '3/31/2013 11:36'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.493';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.115'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 3/31/2013 11:36'!
version1292: spec
	<version: '1.292' imports: #('0.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.291 : Improvement of the force based layout. Thanks Dennis!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '3/31/2013 11:36'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.493';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.115'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 3/31/2013 11:54'!
version1293: spec
	<version: '1.293' imports: #('0.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.292 : removed unused method and added a comment'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '3/31/2013 11:54'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.494';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.115'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 3/31/2013 12:06'!
version1294: spec
	<version: '1.294' imports: #('0.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.293 : added a small comment'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '3/31/2013 12:06'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.495';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.115'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 3/31/2013 12:15'!
version1295: spec
	<version: '1.295' imports: #('0.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.294 : Fix by Juraj.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '3/31/2013 12:15'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.495';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.116'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 3/31/2013 18:18'!
version1296: spec
	<version: '1.296' imports: #('0.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.295 : fixing undeterministic tests with force layout'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '3/31/2013 18:18'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.496';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.116'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 3/31/2013 22:01'!
version1297: spec
	<version: '1.297' imports: #('0.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.296 : Integrated many fixes'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '3/31/2013 22:01'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.496';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.116'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/4/2013 09:00'!
version1298: spec
	<version: '1.298' imports: #('0.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.297 : Fixed Issue 307:	Bug when exporting SVG'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/4/2013 09:00'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.502';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.116'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/5/2013 15:20'!
version1299: spec
	<version: '1.299' imports: #('0.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.298 : Added a superclass ROAbstractPopupTest. A bit of cleaning'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/5/2013 15:20'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.503';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.117'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/4/2012 00:56'!
version129: spec
	<version: '1.29' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.28 : Fixe  Issue 21:	PopupView in ROMondrianViewBuilder in VW not working correctly
1.29 : Added blue color'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/4/2012 00:56'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.206';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.43'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/20/2012 23:25'!
version12: spec
	<version: '1.2' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.1 : Minor fix in ROExample. A test has been moved to platform specific since it has a reference to PackagesInfo
1.2 : Moved an example to PharoSpecific Example. The #image example caused an undeclared reference in VW.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/20/2012 23:25'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.180';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.33'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/6/2013 23:14'!
version1300: spec
	<version: '1.300' imports: #('0.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.299 : Fixed Issue 308:	Large popup in the wrong place'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/6/2013 23:14'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.503';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.116'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/6/2013 23:33'!
version1301: spec
	<version: '1.301' imports: #('0.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.300 : Fixed Issue 309:	empty categories are listed in the examples'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/6/2013 23:33'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.503';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.117'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/7/2013 00:04'!
version1302: spec
	<version: '1.302' imports: #('0.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.301 : Roassal example about drawing'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/7/2013 00:04'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.504';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.117'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/7/2013 00:27'!
version1303: spec
	<version: '1.303' imports: #('0.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.302 : Fixed Issue 310:	Slow with inner nodes'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/7/2013 00:27'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.505';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.117'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/7/2013 07:43'!
version1304: spec
	<version: '1.304' imports: #('0.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.303 : Having edges that show up when you enter a node is a recurrent need.
I have worked on some easy way to make this possible.

Using the Roassal low level api:
-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
| view rawView el1 el2 el3 |
rawView := ROView new.
rawView add: (el1 := ROBox element size: 20).
rawView add: (el2 := ROBox element size: 20).
rawView add: (el3 := ROBox element size: 20).
ROCircleLayout on: (Array with: el1 with: el2 with: el3).
	
el1 @ RODraggable.
el2 @ RODraggable.
el3 @ RODraggable.
	
el1 @ (RODynamicEdge toAll: (Array with: el2 with: el3) using: (ROLine arrowed color: Color red)).

rawView open
-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=


Using the Mondrian builder:
-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
view interaction 
	dynamicEdge: [ :model | (Array with: 10 with: 20 with: 30) copyWithout: model ]
	using: (ROLine arrowed color: Color red).
view shape rectangle size: 20.
view nodes: (Array with: 10 with: 20 with: 30).
view circleLayout.
-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/7/2013 07:43'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.506';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.117'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/8/2013 12:28'!
version1305: spec
	<version: '1.305' imports: #('0.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.304 : 
	- Fixed Issue 311:	ROHorizontalLineLayout>>positionOriginalPointer: buggy
	- cleaned a bit
	- testing ROPharoHTMLExporterTest'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/8/2013 12:28'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.503';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.117'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/8/2013 16:25'!
version1306: spec
	<version: '1.306' imports: #('0.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.305 : Fixed Issue 311:	ROHorizontalLineLayout>>positionOriginalPointer: buggy'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/8/2013 16:25'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.503';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.117'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/8/2013 17:03'!
version1307: spec
	<version: '1.307' imports: #('0.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.306 : merged'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/8/2013 17:03'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.503';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.117'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/8/2013 17:23'!
version1308: spec
	<version: '1.308' imports: #('0.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.307 : Merged'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/8/2013 17:23'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.507';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.118'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/8/2013 18:12'!
version1309: spec
	<version: '1.309' imports: #('0.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.308 : Fixing Roassal.Core.Tests.ROEventTest.testProperlyInitialized '.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/8/2013 18:12'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.508';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.118'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/5/2012 10:06'!
version130: spec
	<version: '1.30' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.29 : Added blue color
1.30 : Pair programming with Dennis on graph transformation (going from edges-based to nesting-based)'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/5/2012 10:06'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.207';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.43'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/9/2013 08:53'!
version1310: spec
	<version: '1.310' imports: #('0.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.309 : Fixed Issue 312:	Bugfix for ROTreeMapLayout'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/9/2013 08:53'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.509';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.118'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/10/2013 17:29'!
version1311: spec
	<version: '1.311' imports: #('0.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.310 : Fixed Issue 313:	RODynamicEdge cannot be combined'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/10/2013 17:29'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.510';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.118'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 4/11/2013 16:24'!
version1312: spec
	<version: '1.312' imports: #('0.5-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.311 : Big big speed improvement'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '4/11/2013 16:24'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.515';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.119'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/5/2012 10:32'!
version131: spec
	<version: '1.31' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.30 : Pair programming with Dennis on graph transformation (going from edges-based to nesting-based)
1.31 : Added ROElement>>remove. Note that some of the tests are yellow. Checking the cycle is not finished yet. Working on that.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/5/2012 10:32'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.208';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.43'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/5/2012 10:47'!
version132: spec
	<version: '1.32' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.31 : Added ROElement>>remove. Note that some of the tests are yellow. Checking the cycle is not finished yet. Working on that.
1.32 : removed the nodes when we transform them. Pair programmed with Dennis'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/5/2012 10:47'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.209';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.43'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/5/2012 11:12'!
version133: spec
	<version: '1.33' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.32 : removed the nodes when we transform them. Pair programmed with Dennis
1.33 : Removed the failing tests'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/5/2012 11:12'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.210';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.43'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/5/2012 14:11'!
version134: spec
	<version: '1.34' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.33 : Removed the failing tests
1.34 : Attempt for the scrollbar. Redefined ROCamera>>height'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/5/2012 14:11'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.211';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.43'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/5/2012 23:24'!
version135: spec
	<version: '1.35' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.34 : Attempt for the scrollbar. Redefined ROCamera>>height
1.35 : Added an example with a scrollbar'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/5/2012 23:24'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.212';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.44'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/11/2012 23:39'!
version136: spec
	<version: '1.36' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.35 : Added an example with a scrollbar
1.36 :
Issue 75:	ROLabelElement should be removed

Issue 76:	Rename ROMondrianViewBuilder>>container into raw

Issue 77: Announcer. ROView has a reference of Announcer, whereas it should refer ROAnnouncer instead.

Issue 78:	ROForceBaseLayout should be parametrizable
'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/11/2012 23:39'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.213';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.45'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/13/2012 00:47'!
version137: spec
	<version: '1.37' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.36 :
Issue 75:	ROLabelElement should be removed

Issue 76:	Rename ROMondrianViewBuilder>>container into raw

Issue 77: Announcer. ROView has a reference of Announcer, whereas it should refer ROAnnouncer instead.

Issue 78:	ROForceBaseLayout should be parametrizable

1.37 : 
Fixed Issue 32:	Turn ROArrowedLine into a shape
Pair programmed with james Swaine during Dyla''12'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/13/2012 00:47'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.215';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.46'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/16/2012 00:52'!
version138: spec
	<version: '1.38' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.37 : 
Fixed Issue 32:	Turn ROArrowedLine into a shape
Pair programmed with james Swaine during Dyla''12
1.38 : ROElement>>remove does not raise an error anymore if the element is not part of a view. Thanks Dennis for suggesting this'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/16/2012 00:52'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.216';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.46'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/18/2012 15:17'!
version139: spec
	<version: '1.39' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.38 : ROElement>>remove does not raise an error anymore if the element is not part of a view. Thanks Dennis for suggesting this
1.39 : Fixed Issue 79:	Cache and color
http://code.google.com/p/objectprofile/issues/detail?id=79

1.39 : element can now have attributes. Useful for the highlighting. '.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/18/2012 15:17'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.218';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.46'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/21/2012 10:28'!
version13: spec
	<version: '1.3' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.2 : Moved an example to PharoSpecific Example. The #image example caused an undeclared reference in VW.
1.3 : Removed an unused method, findElementIn:'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/21/2012 10:28'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.181';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.33'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/18/2012 15:57'!
version140: spec
	<version: '1.40' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.39 : element can now have attributes. Useful for the highlighting. 
1.40 : - Added size for arrow. - added action to remove a node'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/18/2012 15:57'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.219';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.46'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/18/2012 16:04'!
version141: spec
	<version: '1.41' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.40 : - Added size for arrow. - added action to remove a node
1.41 : Moved the item in the world menu'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/18/2012 16:04'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.219';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.47'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/18/2012 20:52'!
version142: spec
	<version: '1.42' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.41 : Moved the item in the world menu
1.42 : Fix in the choose layout example'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/18/2012 20:52'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.220';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.47'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/19/2012 10:19'!
version143: spec
	<version: '1.43' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.42 : Fix in the choose layout example
1.43 : Example of latent semantic indexing '.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/19/2012 10:19'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.221';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.47'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/24/2012 10:50'!
version144: spec
	<version: '1.44' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.43 : Example of latent semantic indexing 
1.44 : Making sure all the unit tests use ROTest. All the tests are green. Fixed Issue 80:	ROTest in Roassal
1.44 : Worked on the expandable nodes'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/24/2012 10:50'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.223';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.47'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/27/2012 09:51'!
version145: spec
	<version: '1.45' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.44 : Worked on the expandable nodes
1.45 : Patched ROGraphTransformation: It should also be possible that multiple rootNodes are found, not just on. Thanks Dennis!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/27/2012 09:51'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.224';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.47'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 6/30/2012 14:29'!
version146: spec
	<version: '1.46' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.45 : Patched ROGraphTransformation: It should also be possible that multiple rootNodes are found, not just on. Thanks Dennis!!
1.46 : Fixed Issue 85:	ROGridLayout and lineCounter. Thanks Usman!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '6/30/2012 14:29'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.225';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.47'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/2/2012 16:38'!
version147: spec
	<version: '1.47' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.46 : Fixed Issue 85:	ROGridLayout and lineCounter. Thanks Usman!!
1.47 : Normalizer added. New examples and tests have been added when migrating from Mondrian'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/2/2012 16:38'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.226';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.47'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/2/2012 17:14'!
version148: spec
	<version: '1.48' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.47 : Normalizer added. New examples and tests have been added when migrating from Mondrian
1.48 : Fixed Issue 88:	Color and edges'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/2/2012 17:14'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.227';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.47'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/3/2012 00:09'!
version149: spec
	<version: '1.49' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.48 : Fixed Issue 88:	Color and edges
1.49 : Making sure VW is happy when being loaded. a lot of {} were in the code of the normalizers'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/3/2012 00:09'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.228';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.47'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/21/2012 21:41'!
version14: spec
	<version: '1.4' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.3 : Removed an unused method, findElementIn:
1.4 :'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/21/2012 21:41'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.181';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.34'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/3/2012 13:51'!
version150: spec
	<version: '1.50' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.49 : Making sure VW is happy when being loaded. a lot of {} were in the code of the normalizers
1.50 : Fixed Issue 90:	if:popupText: in the builder would be useful'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/3/2012 13:51'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.229';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.47'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/3/2012 18:37'!
version151: spec
	<version: '1.51' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.50 : Fixed Issue 90:	if:popupText: in the builder would be useful
1.51 : Fixed a bug for the highlighting'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/3/2012 18:37'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.230';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.47'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/4/2012 00:06'!
version152: spec
	<version: '1.52' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.51 : Fixed a bug for the highlighting
1.52 : All tests are green. Changed the superclass of the normalizer. Fixed  Issue 92:	Superclass of the normalizer
'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/4/2012 00:06'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.231';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.47'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/4/2012 00:59'!
version153: spec
	<version: '1.53' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.52 : All tests are green. Changed the superclass of the normalizer. Fixed  Issue 92:	Superclass of the normalizer

1.53 : Making VW happy...'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/4/2012 00:59'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.232';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.48'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/4/2012 01:07'!
version154: spec
	<version: '1.54' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.53 : Making VW happy...
1.54 : Removed the last reference of SmallDictionary'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/4/2012 01:07'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.233';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.48'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/4/2012 16:37'!
version155: spec
	<version: '1.55' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.54 : Removed the last reference of SmallDictionary
1.55 : Fixed Issue 95:	Highlighting twice the same node'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/4/2012 16:37'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.234';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.48'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/6/2012 13:02'!
version156: spec
	<version: '1.56' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.55 : Fixed Issue 95:	Highlighting twice the same node
1.56 : fixed a bug in Roassal with highlight'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/6/2012 13:02'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.235';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.48'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/7/2012 07:49'!
version157: spec
	<version: '1.57' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.56 : fixed a bug in Roassal with highlight
1.57 : Worked on the if:popupText:'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/7/2012 07:49'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.236';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.48'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/7/2012 14:21'!
version158: spec
	<version: '1.58' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.57 : Worked on the if:popupText:
1.58 : minor fix'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/7/2012 14:21'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.237';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.48'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/9/2012 08:38'!
version159: spec
	<version: '1.59' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.58 : minor fix
1.59 : Fixed if:popupText: and fixed the tests for VW'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/9/2012 08:38'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.238';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.48'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/21/2012 22:13'!
version15: spec
	<version: '1.5' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.4 :
1.5 : Two popups cannot appear at the same time. http://code.google.com/p/objectprofile/issues/detail?id=48'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/21/2012 22:13'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.182';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.35'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/9/2012 10:17'!
version160: spec
	<version: '1.60' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.59 : Fixed if:popupText: and fixed the tests for VW
1.60 : minor fix for VW'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/9/2012 10:17'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.239';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.48'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/15/2012 13:33'!
version161: spec
	<version: '1.61' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.60 : minor fix for VW
1.61 :
  - fixed Issue 97:	Adding an interaction remove the popupText 
  - fixed Issue 98:	Border shape only takes color value
  - fixed Issue 99:	ROExample>>arrowedLine raises an error 
  - fixed Issue 100:	New step in the tutorial to conditionally color nodes'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/15/2012 13:33'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.240';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.49'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/16/2012 08:17'!
version162: spec
	<version: '1.62' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.61 :
  - fixed Issue 97:	Adding an interaction remove the popupText 
  - fixed Issue 98:	Border shape only takes color value
  - fixed Issue 99:	ROExample>>arrowedLine raises an error 
  - fixed Issue 100:	New step in the tutorial to conditionally color nodes
1.62 : Slightly Increased the coverage'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/16/2012 08:17'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.241';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.50'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/16/2012 20:37'!
version163: spec
	<version: '1.63' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.62 : Slightly Increased the coverage
1.63 : fixed some typos (which were found by VW) '.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/16/2012 20:37'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.242';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.50'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/20/2012 18:18'!
version164: spec
	<version: '1.64' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.63 : fixed some typos (which were found by VW) 
1.64 : Fixed Issue 103:	ROEdgeDrivenLayout doesn''t work with Sets of elements. Thanks Daan!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/20/2012 18:18'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.243';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.50'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/23/2012 12:21'!
version165: spec
	<version: '1.65' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.64 : Fixed Issue 103:	ROEdgeDrivenLayout doesn''t work with Sets of elements. Thanks Daan!!
1.65 : Fixed Issue 104:	Odd drag and drop when zooming in'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/23/2012 12:21'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.244';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.50'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/25/2012 09:39'!
version166: spec
	<version: '1.66' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.65 : Fixed Issue 104:	Odd drag and drop when zooming in
1.66 : Added an explicit stack in the builder. We also introduced ROMondrianFrame to model a stack frame.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/25/2012 09:39'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.245';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.50'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/25/2012 11:41'!
version167: spec
	<version: '1.67' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.66 : Added an explicit stack in the builder. We also introduced ROMondrianFrame to model a stack frame.
1.67 : Fixed http://code.google.com/p/moose-technology/issues/detail?id=806'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/25/2012 11:41'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.246';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.50'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/25/2012 16:52'!
version168: spec
	<version: '1.68' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.67 : Fixed http://code.google.com/p/moose-technology/issues/detail?id=806
1.68 : Fixed Issue 107:	Have an easy way to select rendering platform'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/25/2012 16:52'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.247';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.51'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/25/2012 17:24'!
version169: spec
	<version: '1.69' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.68 : Fixed Issue 107:	Have an easy way to select rendering platform
1.69 : Loadable version in VisualWorks'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/25/2012 17:24'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.248';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.52'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/22/2012 00:51'!
version16: spec
	<version: '1.6' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.5 : Two popups cannot appear at the same time. http://code.google.com/p/objectprofile/issues/detail?id=48
1.6 : better implementation of parentBehavior. The parent element can now decide whether it has to grow or not. Before it was the children who can decide, which is quite odd.'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/22/2012 00:51'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.183';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.35'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/25/2012 17:30'!
version170: spec
	<version: '1.70' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.69 : Loadable version in VisualWorks
1.70 : recatogized some methods'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/25/2012 17:30'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.248';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.53'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/25/2012 18:08'!
version171: spec
	<version: '1.71' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.70 : recatogized some methods
1.71 : Added the visual element of the host platform in ROPlatform. This is necessary for the Cairo platform, built upon the VW platform'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/25/2012 18:08'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.249';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.54'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/26/2012 09:36'!
version172: spec
	<version: '1.72' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.71 : Added the visual element of the host platform in ROPlatform. This is necessary for the Cairo platform, built upon the VW platform
1.72 : fixed Issue 109:	Rossal and collections (http://code.google.com/p/moose-technology/issues/detail?id=815). Thanks Tudor Doru Girba!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/26/2012 09:36'.
		spec 
			package: #Roassal with: 'Roassal-TudorGirba.250';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.54'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/26/2012 10:38'!
version173: spec
	<version: '1.73' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.72 : fixed Issue 109:	Rossal and collections (http://code.google.com/p/moose-technology/issues/detail?id=815). Thanks Tudor Doru Girba!!
1.73 : minor method categorization'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/26/2012 10:38'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.251';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.54'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/26/2012 11:54'!
version174: spec
	<version: '1.74' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.73 : minor method categorization
1.74 : Fixed Issue 110:	ROForceBasedLayoutTest >> testLayout fails on Windows'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/26/2012 11:54'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.252';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.54'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/27/2012 16:25'!
version175: spec
	<version: '1.75' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.74 : Fixed Issue 110:	ROForceBasedLayoutTest >> testLayout fails on Windows
1.75 : Fixed Issue 111:	Removing the bitmap generation from the core'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/27/2012 16:25'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.253';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.55'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/27/2012 17:47'!
version176: spec
	<version: '1.76' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.75 : Fixed Issue 111:	Removing the bitmap generation from the core
1.76 : renaming ROAbstractCanvas.canvas into nativeCanvas'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/27/2012 17:47'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.254';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.56'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/28/2012 22:29'!
version177: spec
	<version: '1.77' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.76 : renaming ROAbstractCanvas.canvas into nativeCanvas
1.77 : Committed a new example tab in the easel. '.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/28/2012 22:29'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.255';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.57'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/28/2012 22:53'!
version178: spec
	<version: '1.78' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.77 : Committed a new example tab in the easel. 
1.78 : Reorganizing a bit the Mondrian examples.
Fixed Issue 113:	Add an example for the attach point in Roassal
Fixed Issue 112:	Add a legend in the Roassal example'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/28/2012 22:53'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.256';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.57'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/29/2012 08:59'!
version179: spec
	<version: '1.79' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.78 : Reorganizing a bit the Mondrian examples.
Fixed Issue 113:	Add an example for the attach point in Roassal
Fixed Issue 112:	Add a legend in the Roassal example
1.79 : Fixed Issue 114:	HorizontalTreeLayout 
the example have also been updated accordingly '.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/29/2012 08:59'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.257';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.57'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/22/2012 01:01'!
version17: spec
	<version: '1.7' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.6 : better implementation of parentBehavior. The parent element can now decide whether it has to grow or not. Before it was the children who can decide, which is quite odd.
1.7 : Minor bug fixed in ROAbstractView>>blackHole (basicNew -> new)'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/22/2012 01:01'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.184';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.35'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/29/2012 09:27'!
version180: spec
	<version: '1.80' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.79 : Fixed Issue 114:	HorizontalTreeLayout 
the example have also been updated accordingly 
1.80 : Fixed Issue 115:	adding menu to the background 
For example:
view nodes: (1 to: 50).
view raw @ (ROMenuActivable new 
				item: ''hello'' action: #inspect;
				item: ''world'' action: #inspect).    

'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/29/2012 09:27'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.258';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.57'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/29/2012 10:17'!
version181: spec
	<version: '1.81' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.80 : Fixed Issue 115:	adding menu to the background 
For example:
view nodes: (1 to: 50).
view raw @ (ROMenuActivable new 
				item: ''hello'' action: #inspect;
				item: ''world'' action: #inspect).    


1.81 : Fixed Issue 116:	Example>colors>normalizer is not really interesting'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/29/2012 10:17'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.259';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.57'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/29/2012 10:26'!
version182: spec
	<version: '1.82' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.81 : Fixed Issue 116:	Example>colors>normalizer is not really interesting
1.82 : Fixed Issue 118:	title of the example'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/29/2012 10:26'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.259';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.58'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/29/2012 12:49'!
version183: spec
	<version: '1.83' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.82 : Fixed Issue 118:	title of the example
1.83 : Fixed Issue 120:	Roassal in VW has 3 undeclared variables'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/29/2012 12:49'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.260';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.59'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/30/2012 00:09'!
version184: spec
	<version: '1.84' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.83 : Fixed Issue 120:	Roassal in VW has 3 undeclared variables
1.84 : 
  - Fixed Issue 122:	Vertical Arrow and Reversed Arrow
  - Fixed Issue 121:	OrthoVerticalLine'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/30/2012 00:09'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.261';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.60'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/30/2012 00:19'!
version185: spec
	<version: '1.85' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.84 : 
  - Fixed Issue 122:	Vertical Arrow and Reversed Arrow
  - Fixed Issue 121:	OrthoVerticalLine
1.85 : http://code.google.com/p/moose-technology/issues/detail?id=822  
Thanks Doru!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/30/2012 00:19'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.267';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.60'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/30/2012 11:27'!
version186: spec
	<version: '1.86' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.85 : http://code.google.com/p/moose-technology/issues/detail?id=822  
Thanks Doru!!
1.86 : Cleaning'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/30/2012 11:27'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.267';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.61'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 7/30/2012 17:08'!
version187: spec
	<version: '1.87' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.86 : Cleaning
1.87 : minor cleaning'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '7/30/2012 17:08'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.268';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.61'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/1/2012 16:32'!
version188: spec
	<version: '1.88' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.87 : minor cleaning
1.88 : Fixed Issue Roassal overwriting window borders
 http://code.google.com/p/moose-technology/issues/detail?id=817
http://code.google.com/p/objectprofile/issues/detail?id=123
'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/1/2012 16:32'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.268';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.62'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/2/2012 17:50'!
version189: spec
	<version: '1.89' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.88 : Fixed Issue Roassal overwriting window borders
 http://code.google.com/p/moose-technology/issues/detail?id=817
http://code.google.com/p/objectprofile/issues/detail?id=123

1.89 : Fixed Issue 124:	buttons remains after ROMondiranExample >> chooseLayout'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/2/2012 17:50'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.268';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.63'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/22/2012 08:50'!
version18: spec
	<version: '1.8' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.7 : Minor bug fixed in ROAbstractView>>blackHole (basicNew -> new)
1.8 : Making invisible edges. Fix Issue #51'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/22/2012 08:50'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.185';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.35'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/2/2012 18:12'!
version190: spec
	<version: '1.90' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.89 : Fixed Issue 124:	buttons remains after ROMondiranExample >> chooseLayout
1.90 : Issue 125:	Issue 824:	Roassal hover text should disappear when dragging node
http://code.google.com/p/moose-technology/issues/detail?id=824
http://code.google.com/p/objectprofile/issues/detail?id=125'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/2/2012 18:12'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.269';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.63'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/3/2012 11:51'!
version191: spec
	<version: '1.91' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.90 : Issue 125:	Issue 824:	Roassal hover text should disappear when dragging node
http://code.google.com/p/moose-technology/issues/detail?id=824
http://code.google.com/p/objectprofile/issues/detail?id=125
1.91 : Fixed Issue 823:	buttons remains after ROMondrianExample >> chooseLayout'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/3/2012 11:51'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.270';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.63'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/5/2012 11:04'!
version192: spec
	<version: '1.92' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.91 : Fixed Issue 823:	buttons remains after ROMondrianExample >> chooseLayout
1.92 : Added ROOrthoHorizontalLineShape, ROHorizontalArrow, ROReversedHorizontalArrow. Modified examples to show a several combinations of attachPoint method and offset.
Thanks Ben!!!! Really cool!!'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/5/2012 11:04'.
		spec 
			package: #Roassal with: 'Roassal-BenComan.271';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.63'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/5/2012 12:06'!
version193: spec
	<version: '1.93' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.92 : Added ROOrthoHorizontalLineShape, ROHorizontalArrow, ROReversedHorizontalArrow. Modified examples to show a several combinations of attachPoint method and offset.
Thanks Ben!!!! Really cool!!
1.93 : colorFor: for labels'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/5/2012 12:06'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.272';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.63'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/19/2012 09:59'!
version194: spec
	<version: '1.94' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.93 : colorFor: for labels
1.94 : 
	Fixed Issue 129:	Strange popupView in Roassal
	http://code.google.com/p/moose-technology/issues/detail?id=827'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/19/2012 09:59'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.273';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.63'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/19/2012 10:15'!
version195: spec
	<version: '1.95' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.94 : 
	Fixed Issue 129:	Strange popupView in Roassal
	http://code.google.com/p/moose-technology/issues/detail?id=827
1.95 : Fixed Issue 130:	ROBeginingAnimation>>isOver'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/19/2012 10:15'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.274';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.64'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/19/2012 11:26'!
version196: spec
	<version: '1.96' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.95 : Fixed Issue 130:	ROBeginingAnimation>>isOver
1.96 : commented addLast: Thanks Ben for the suggestion'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/19/2012 11:26'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.275';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.64'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/19/2012 11:51'!
version197: spec
	<version: '1.97' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.96 : commented addLast: Thanks Ben for the suggestion
1.97 : Issue 131:	ROMorph>>mouseOver:
	http://code.google.com/p/moose-technology/issues/detail?id=828'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/19/2012 11:51'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.276';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.65'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/20/2012 08:59'!
version198: spec
	<version: '1.98' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.97 : Issue 131:	ROMorph>>mouseOver:
	http://code.google.com/p/moose-technology/issues/detail?id=828
1.98 : 
	Fixed Issue 132:	ROElement, ROEdge
	Fixed Issue 133:	ROShape>>removeShape:'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/20/2012 08:59'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.277';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.65'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 8/20/2012 11:13'!
version199: spec
	<version: '1.99' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.98 : 
	Fixed Issue 132:	ROElement, ROEdge
	Fixed Issue 133:	ROShape>>removeShape:
1.99 : Fixed Issue 136:	Roassal hover popup on edges
	http://code.google.com/p/moose-technology/issues/detail?id=826'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '8/20/2012 11:13'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.278';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.65'. ].
! !

!ConfigurationOfRoassal methodsFor: 'versions' stamp: 'AlexandreBergel 5/22/2012 14:00'!
version19: spec
	<version: '1.9' imports: #('0.2-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: '1.8 : Making invisible edges. Fix Issue #51
1.9 : Added a sortElementsWith: on ROAbstractView to reorder the nodes. Added a doPost: on ROLayout'.
		spec author: 'AlexandreBergel'.
		spec timestamp: '5/22/2012 14:00'.
		spec 
			package: #Roassal with: 'Roassal-AlexandreBergel.186';
			package: #RoassalMorphic with: 'RoassalMorphic-AlexandreBergel.35'. ].
! !
